@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -68,7 +72,7 @@ module SiSU_Assemble
     end
     def download_images(download_from,images_array)
       path="#{@env.path.processing}/external_document/image"
-      File.mkpath(path) unless FileTest.directory?(path)
+      mkdir_p(path) unless FileTest.directory?(path)
       images_array.each do |i|
         image="#{path}/#{i}"
         imagefile=File.new(image,'w+')
@@ -78,12 +82,12 @@ module SiSU_Assemble
         imagefile.close
       end
       output_path="#{@env.path.webserv}/#{@env.path.stub_pwd}/_sisu/image_external"
-      File.mkpath(output_path) unless FileTest.directory?(output_path)
+      mkdir_p(output_path) unless FileTest.directory?(output_path)
       SiSU_Env::System_call.new("#{path}/*",output_path,'q').rsync
     end
     def download_doc_skin(doc_skin) #first element in array is source url
       path="#{@env.path.processing}/external_document/skin/doc"
-      File.mkpath(path) unless FileTest.directory?(path)
+      mkdir_p(path) unless FileTest.directory?(path)
       download_from=doc_skin.shift
       doc_skin.each do |i|
         skin="#{path}/#{i}.rb"
@@ -119,7 +123,7 @@ module SiSU_Assemble
     end
     def download_images(download_from,images_array)
       path="#{@env.path.processing}/external_document/image"
-      File.mkpath(path) unless FileTest.directory?(path)
+      mkdir_p(path) unless FileTest.directory?(path)
       images_array.each do |i|
         image="#{path}/#{i}"
         unless FileTest.exists?(image)
@@ -133,7 +137,7 @@ module SiSU_Assemble
     end
     def download_doc_skin(doc_skin) #first element in array is source url
       path="#{@env.path.processing}/external_document/skin/doc"
-      File.mkpath(path) unless FileTest.directory?(path)
+      mkdir_p(path) unless FileTest.directory?(path)
       download_from=doc_skin.shift
       doc_skin.each do |i|
         skin="#{path}/#{i}.rb"
@@ -186,13 +190,10 @@ module SiSU_Assemble
       tell=SiSU_Screen::Ansi.new(@opt.cmd,'Composite Document',@opt.fns)
       tell.grey_title_hi unless @opt.cmd =~/q/
       para=data.each do |para|
-        if para =~/^r\{(.+?)\}/ \
-        or para =~/^(?:<<\s*)\{(.+?)\}(?:req(?:quire)?\b|\s*\})?/ \
+        if para =~/^<<\s+(\S+?\.ss[it])$/ \
+        or para =~/^<<\{(\S+?\.ss[it])\}$/ \
         or para =~/^(?:<<\s*)\|(\S+?)\|@\|.+?\|(?:req(?:quire)?\b|\s*\})?/ \
-        or para =~/^(?:<<\s*)<(?:URL|url):(\S+?)>(?:req(?:require)\b|\s*\})?/ \
-        or para =~/^\{(.+?)\}(?:req(?:require)?)\b/ \
-        or para =~/^\|(\S+?)\|@\|.+?\|(?:req(?:require)?)\b/ \
-        or para =~/^<(?:URL|url):(\S+?)>(?:req(?:require))\b/
+        or para =~/^r\{(.+?)\}/ #depreciated
           loadfile=$1.strip
           tell=SiSU_Screen::Ansi.new(@opt.cmd,'loading:',loadfile)
           tell.txt_grey if @opt.cmd =~/[MVv]/
