@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -56,23 +60,22 @@
 
 =end
 module SiSU_Concordance
-  require "#{SiSU_lib}/param"
+  require "#{SiSU_lib}/particulars"
+  include SiSU_Particulars
   require "#{SiSU_lib}/sysenv"
-  require "#{SiSU_lib}/defaults"
-  require "#{SiSU_lib}/dal"
-  include SiSU_Param
   include SiSU_Env
+  require "#{SiSU_lib}/defaults"
   include SiSU_Viz
   require "#{SiSU_lib}/html_format_css"
   include SiSU_HTML_Format
   class Source
     def initialize(opt)
       @opt=opt
+      @particulars=SiSU_Particulars::Combined_singleton.instance.get_all(opt)
     end
     def read
       begin
-        @md=SiSU_Param::Parameters.new(@opt).get
-        @env=SiSU_Env::Info_env.new(@md.fns)
+        @env,@md=@particulars.env,@particulars.md
         loc=@env.url.output_tell
         tool=if @md.cmd =~/[MVv]/; "#{@env.program.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:concordance]}"
         else ''
@@ -82,7 +85,7 @@ module SiSU_Concordance
         wordmax=@env.concord_max
         unless @md.wc_words.nil?
           if @md.wc_words < wordmax
-            SiSU_Concordance::Source::Words.new(@md).songsheet
+            SiSU_Concordance::Source::Words.new(@particulars).songsheet
           else
             tell=SiSU_Screen::Ansi.new(@md.cmd,"concordance skipped, large document has over #{wordmax} words (#{@md.wc_words})")
             tell.warn unless @md.cmd =~/q/
@@ -90,7 +93,7 @@ module SiSU_Concordance
         else
           tell=SiSU_Screen::Ansi.new(@md.cmd,"wc (word count) is off, concordance will be processed for all files including those over the max set size of: #{wordmax} words")
           tell.warn unless @md.cmd =~/q/
-          SiSU_Concordance::Source::Words.new(@md).songsheet
+          SiSU_Concordance::Source::Words.new(@particulars).songsheet
         end
       rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
       ensure
@@ -98,22 +101,18 @@ module SiSU_Concordance
     end
     private
     class Doc_title
-      require "#{SiSU_lib}/param"
-      include SiSU_Param
       include SiSU_Viz
       #revisit, both requires (html & shared_xml) needed for stand alone operation (sisu -w [filename])
       require "#{SiSU_lib}/shared_xml"
       require "#{SiSU_lib}/html"
-      def initialize(lnk,md)
-        @md=md
+      def initialize(lnk,env,md)
+        @env,@md=env,md
         @vz=SiSU_Env::Get_init.instance.skin
-        @env=SiSU_Env::Info_env.new(@md.fns)
         file_array=@env.read_source_file(@md.fns)
         txt_path=%{#{@md.dir_out}}
         SiSU_Env::Info_skin.new(@md).select
         @md_title=@md.title
         @fnb=@md.fnb
-        @env=SiSU_Env::Info_env.new
         @lex_button=%{<a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" height="44" width="144" valign="center" src="../_sisu/image/sisu.png" alt="SiSU home --&gt;"></a>}
         @lnk=lnk
         @doc_details =<<WOK
@@ -171,21 +170,17 @@ WOK
     end
     class Words
       require "#{SiSU_lib}/defaults"
-      require "#{SiSU_lib}/param"
       include SiSU_Viz
-      include SiSU_Param
       require "#{SiSU_lib}/html_format_css"
       include SiSU_HTML_Format
       require "#{SiSU_lib}/sysenv"
       include SiSU_Screen
       @@dp=nil
-      def initialize(md)
+      def initialize(particulars)
         begin
           @vz=SiSU_Env::Get_init.instance.skin
-          @md=md
-          @env=SiSU_Env::Info_env.new(@md.fns)
+          @env,@md,@dal_array=particulars.env,particulars.md,particulars.dal_array
           @path="#{@env.path.output}/#{@md.fnb}"
-          @dal_array=SiSU_DAL::Source.new(@md).get # dal file drawn here
           @freq=Hash.new(0)
           @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
           @rxp_to=Regexp.new("<~(\\d+);(?:[oh]|[0-6]:)\\d+;\\w\\d+><#@dp:#@dp>$")
@@ -205,7 +200,7 @@ WOK
       end
       def songsheet
         begin
-          File.mkpath(@path) unless FileTest.directory?(@path)
+          mkdir_p(@path) unless FileTest.directory?(@path)
           @file_index_all=File.open("#@path/#{@md.fn[:concordance]}",'w')
           map_para
         rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
@@ -288,7 +283,7 @@ WOK
         end
         scr='<font size="1" color="#777777" face=times new roman><img border="0" height="15" width="15" src="../_sisu/image/b_doc.png" alt="Full Text">&nbsp;scroll:&nbsp;</font><font size="1" color="#222222" face=times new roman>doc#&nbsp;</font> '
         seg=''
-        @file_index_all << SiSU_Concordance::Source::Doc_title.new('toc',@md).create
+        @file_index_all << SiSU_Concordance::Source::Doc_title.new('toc',@env,@md).create
         for word in @freq.keys.sort! {|a,b| a.downcase<=>b.downcase}
           keyword=SiSU_Concordance::Source::Word.new(word,@freq[word]).html
           if keyword !~ @rxp_excluded0
