@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -138,8 +142,6 @@ module SiSU_document_structure
       data=@data
       @o_array=[]
       node=ocn=ocn_dv=ocn_sp=ocnh=ocnh1=ocnh2=ocnh3=ocnh4=ocnh5=ocnh6=ocno=ocnp=ocnt=ocnc=ocng=ocni=ocnm=ocnu=ocnk=0 # h heading, o other, t table, g group, i image
-      number_small,letter_small=0,0
-      letter=%w( a b c d e f g h i j k l m n o p q r s t u v w x y z )
       node_count_flag=false
       headings='' #where headings omitted an alternative form of ocn heading numbering is required for html and other linking...
       #headings=if @md.ocn.inspect =~/skip=headings/; '^(?:[A-C]|[1-9])~\S* |'
@@ -169,7 +171,7 @@ module SiSU_document_structure
                   ocnh+=1
                   if    para=~/^1~(?:\s+|\S)/ \
                   or para =~@md.lv1
-                    ocnh1+=1
+                    ocnh1+=1                                             #heading
                     ocn_dv,ocn_sp="1:#{ocnh1}","h#{ocnh}"
                   elsif para=~/^2~(?:\s+|\S)/ \
                   or para =~@md.lv2; ocnh2+=1
@@ -189,15 +191,15 @@ module SiSU_document_structure
                   end
                 else
                   ocno+=1
-                  if para=~/<!TZ!>/;                             ocnt+=1 #tables
+                  if para=~/<!TZ!>/;                             ocnt+=1 #table
                     ocn_dv,ocn_sp="o#{ocno}","t#{ocnt}"
-                  elsif para=~/^<:code>/;                        ocnc+=1
+                  elsif para=~/^<:code>/;                        ocnc+=1 #code block
                     ocn_dv,ocn_sp="o#{ocno}","c#{ocnc}"
-                  elsif para=~/^<:(?:group|alt|verse)>/;         ocng+=1
+                  elsif para=~/^<:(?:group|alt|verse)>/;         ocng+=1 #group, poem
                     ocn_dv,ocn_sp="o#{ocno}","g#{ocng}"
-                  elsif para=~/\{\S+?\.(?:png|jpg|gif)\s+/m;         ocni+=1
+                  elsif para=~/\{\S+?\.(?:png|jpg|gif)\s+/m;     ocni+=1 #image
                     ocn_dv,ocn_sp="o#{ocno}","i#{ocni}"
-                  else                                           ocnp+=1
+                  else                                           ocnp+=1 #paragraph
                     ocn_dv,ocn_sp="o#{ocno}","p#{ocnp}"
                   end
                 end
@@ -225,7 +227,7 @@ module SiSU_document_structure
         end
         para.gsub!(/\n\n/,"\n") if para =~/<:(?:code|verse|alt|group)>/ #newlines taken out
         para.gsub!(/(<:(?:code-end)>)/,"\n\\1") if para =~/<:(?:code-end)>/ #newlines added check
-        if para =~/<!Th?¡/; para.gsub!(/(<!Th?¡.+?!)>/,"\\1~#{o[:ocn]};#{o[:lv]};#{o[:type]}>")
+        if para =~/<!Th?¡/u; para.gsub!(/(<!Th?¡.+?!)>/u,"\\1~#{o[:ocn]};#{o[:lv]};#{o[:type]}>")
         end
         @o_array << Struct.new(o).structure if o
       end
