@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -80,8 +84,8 @@ module SiSU_document_structure_tables
         @row[count]=row.split(/\|/)
       end
       @row.compact!
-      widths=if @row[0].to_s =~/^\{(?:t|table)(?:~h)?\s+\d+;/
-        col_width=@row[0].to_s.scan(/\d+/)
+      widths=if @row[0].join =~/^\{(?:t|table)(?:~h)?\s+\d+;/
+        col_width=@row[0].join.scan(/\d+/)
         rem=(100 - col_width[0].to_i)
         col_w=rem/(@row[1].length - 1)
         "#{col_width[0].to_s};" + ("#{col_w};" * (@row[1].length-1))
@@ -93,9 +97,9 @@ module SiSU_document_structure_tables
       w=widths.split(/;/)
       tuned_file=[]
       tuned_file << if para =~/\{(?:t|table)~h(?:\sc\d+;)?[\d; ]*\}/
-        "<!Th¡ c#{@row[2].length}; #{widths}!>"
+        "<!Th#{TS1} c#{@row[2].length}; #{widths}!>"
       elsif para =~/\{(?:t|table)(?:\sc\d+;)?[\d; ]*\}/
-        "<!T¡ c#{@row[2].length}; #{widths}!>"
+        "<!T#{TS1} c#{@row[2].length}; #{widths}!>"
       end
       @row.each do |l|
         l << '' if l.length == (@row[1].length - 1)
@@ -106,9 +110,9 @@ module SiSU_document_structure_tables
           l.each do |c|
             n +=1                                                                      #'<td>' + c + '</td>'
             table << if c =~/\A(?:\n)?\s*\Z/
-              "¡¡#{w[n]}¡" + ' '
+              "#{TS1}#{TS1}#{w[n]}#{TS1}" + ' '
             else
-              "¡¡#{w[n]}¡" + c.strip
+              "#{TS1}#{TS1}#{w[n]}#{TS1}" + c.strip
             end
           end
           table << '!>'                                                                  #'</tr>'
@@ -137,8 +141,8 @@ module SiSU_document_structure_tables
             instructions=$1
             @@column=instructions.split(/;\s*/)
             @@columns=@@column[0]
-            para.gsub!(/^table\{~h\s+(c\d+?;.+?)$/,'<!Th¡ \1!>')
-            para.gsub!(/^table\{\s+(c\d+?;.+?)$/,'<!T¡ \1!>')
+            para.gsub!(/^table\{~h\s+(c\d+?;.+?)$/,"<!Th#{TS1} \\1!>")
+            para.gsub!(/^table\{\s+(c\d+?;.+?)$/,"<!T#{TS1} \\1!>")
             @@flag['table_to']=true
           end
           if @@flag['table_to'] \
@@ -157,10 +161,10 @@ module SiSU_document_structure_tables
           and para =~/\S/
             @@counter=1
             sub_array=para.dup
-            @@line_mode=sub_array.scan(/.+/)
+            @@line_mode=sub_array.scan(/.+/u)
             Tables.new(@md,@@line_mode).tr_td
             para=@@line_mode.join
-            para.gsub!(/(.*\S+.*)\Z/m,'<!\1!>') unless para =~/<!Th?¡/
+            para.gsub!(/(.*\S+.*)\Z/m,'<!\1!>') unless para =~/<!Th?#{TS1}/u
           end
           para.gsub!(/\n/,' ')
           para.strip!
@@ -179,7 +183,10 @@ module SiSU_document_structure_tables
       data.each do |line|
         if @@counter <= @@columns.to_i \
         and line !~/(\}T\s*$|<:table[-_](close|end)>|<!TZ!>)/
-          line.gsub!(/(.+)/,"¡¡#{@@column[@@counter]}¡\\1") unless line =~/<!Th?¡/
+          #if line.encoding.inspect =~/Encoding:ASCII-8BIT/
+          #  line=line.force_encoding('utf-8')
+          #end
+          line.gsub!(/(.+)/,"#{TS1}#{TS1}#{@@column[@@counter]}#{TS1}\\1") unless line =~/<!Th?#{TS1}/u
           @@counter+=1
         end
       end
@@ -188,3 +195,6 @@ module SiSU_document_structure_tables
   end
 end
 __END__
+#p line.encoding
+@data.each {|x| p x.encoding }
+p para if para.encoding.inspect =~/Encoding:ASCII-8BIT/
