@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -59,14 +63,15 @@ module SiSU_DB_import
   require "#{SiSU_lib}/db_columns"
   require "#{SiSU_lib}/db_load_tuple"
   require "#{SiSU_lib}/shared_html_lite"
+  #require 'sqlite3'
   class Import < SiSU_DB_columns::Column_size
     include SiSU_Param
     include SiSU_Screen
     @@dl=nil
     @@hname=nil
     attr_accessor :tp
-    def initialize(opt,conn='',sql_type='pg')
-      @opt,@conn,@sql_type=opt,conn,sql_type
+    def initialize(opt,conn,file,sql_type='pg')
+      @opt,@conn,@file,@sql_type=opt,conn,file,sql_type
       @cX=SiSU_Screen::Ansi.new(@opt.cmd).cX
       @env=SiSU_Env::Info_env.new(@opt.fns)
       @dal="#{@env.path.dal}"
@@ -82,11 +87,19 @@ module SiSU_DB_import
       @col[:ocn]=''
       @counter={}
       sql='SELECT MAX(lid) FROM documents'
-      @col[:lid]=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
-      @col[:lid] ||=0
+      begin
+        @col[:lid] ||=0
+        @col[:lid]=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
+      rescue
+      end
+      @col[:lid] =0 if @col[:lid].nil? or @col[:lid].to_s.empty?
       sql='SELECT MAX(nid) FROM endnotes'
-      @id_n=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
-      @id_n ||=0
+      begin
+        @id_n ||=0
+        @id_n=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
+      rescue
+      end
+      @id_n =0 if @col[:lid].nil? or @col[:lid].to_s.empty?
       @col[:lv1]=@col[:lv2]=@col[:lv3]=@col[:lv4]=@col[:lv5]=@col[:lv6]=0
       @db=SiSU_Env::Info_db.new
       @@dl ||=SiSU_Env::Info_env.new.digest.length
@@ -100,17 +113,22 @@ module SiSU_DB_import
       tell.print_grey if @opt.cmd =~/v/
       case @sql_type
       when /sqlite/                                                    #fix logic for sqlite !
-        import_db_metadata(@dal_array)
-        import_documents(@dal_array)
-        import_db_urls(@dal_array,@fnm)                                #import OID on/off
-        @conn.commit                                                   #sqlite watch
+        #pf_db_import_transaction_open if @opt =~/M/
+        db_import_metadata
+        db_import_documents(@dal_array)
+        db_import_urls(@dal_array,@fnm)                                #import OID on/off
+        #pf_db_import_transaction_close if @opt =~/M/
+        #@conn.commit
+        #@conn.close
+        #@conn.disconnect
+#sqlite watch
       else
         file_exist=@conn.select_one(%{ SELECT metadata.tid FROM metadata WHERE metadata.filename ~ '#{@opt.fns}'; })
         unless file_exist
           @conn.execute('BEGIN')
-          import_db_metadata(@dal_array)
-          import_documents(@dal_array)
-          import_db_urls(@dal_array,@fnm)                              #import OID on/off
+          db_import_metadata
+          db_import_documents(@dal_array)
+          db_import_urls(@dal_array,@fnm)                              #import OID on/off
           @conn.execute('COMMIT')
         else
           @db=SiSU_Env::Info_db.new
@@ -130,17 +148,21 @@ module SiSU_DB_import
       string.gsub!(/<sup>(\d+)<\/sup>/,'[\1]')
       string.gsub!(/<:i[12]>/,'')
       string.gsub!(/(?:&nbsp\\;)+/,' ')
-      string.gsub!(/<!T[h]?¡.+?!>/,"[TABLE]\n")                                 #tables
-      string.gsub!(/<!¡¡\d+(.+?)!>/,'\1')                                       #tables
-      string.gsub!(/¡¡\d+¡/,' ')                                                #tables
-      string.gsub!(/¡/,' ')                                                     #tables tidy later
+      string.gsub!(/<!T[h]?¡.+?!>/u,"[TABLE]\n")                                 #tables
+      string.gsub!(/<!¡¡\d+(.+?)!>/u,'\1')                                       #tables
+      string.gsub!(/¡¡\d+¡/u,' ')                                                #tables
+      string.gsub!(/¡/u,' ')                                                     #tables tidy later
       string.gsub!(/<.+?>/,'')
       string.gsub!(/\{.+?\.(?:png|jpg|gif).+?\}(?:https?|file|ftp)\\\:\S+ /,' [image] ') # else image names found in search
       string.gsub!(/\s\s+/,' ')
       string.strip!
     end
                                                                                  #% import into database tables
-    def import_db_metadata(dbi_unit)                                             #% import documents - populate database
+    def pf_db_import_transaction_open
+    end
+    def pf_db_import_transaction_close
+    end
+    def db_import_metadata                                                       #% import documents - populate database
       print %{ #{@cX.grey}import documents dbi_unit #{@cX.off} } unless @opt.cmd =~/q/
       @tp={}
       @md=SiSU_Param::Parameters.new(@opt).get
@@ -148,9 +170,13 @@ module SiSU_DB_import
         special_character_escape(@tp[:title])
         @tp[:title_f],@tp[:title_i]='title, ',"'#{@tp[:title]}', "
         sql='SELECT MAX(tid) FROM metadata'
-        id_t=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
-        @@id_t=id_t if id_t
-        @@id_t ||=0
+        begin
+          @@id_t ||=0
+          id_t=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
+          @@id_t=id_t if id_t
+        rescue
+        end
+        @@id_t =0 if @col[:lid].nil? or @col[:lid].to_s.empty?
         @@id_t+=1 #bug related, needs to be performed once at start of file, but consider moving, as, placed here it means program will fail if document header lacks 0~title
         puts %{\n#{@cX.grey}Processing file number#{@cX.off}: #{@cX.green}#{@@id_t}#{@@cX.off}} unless @opt.cmd =~/q/
       end
@@ -337,17 +363,17 @@ module SiSU_DB_import
       #end
       #if @md.ruby_version;                      special_character_escape(@md.ruby_version)
       SiSU_DB_DBI::Test.new(self,@opt).verify                          #% import title names, filenames (tuple)
-      t=SiSU_DB_tuple::Load_metadata.new(@conn,@tp,@@id_t)
+      t=SiSU_DB_tuple::Load_metadata.new(@conn,@tp,@@id_t,@opt,@file)
       t.tuple
     end
-    def import_documents(dbi_unit)                                     #% import documents - populate main database table
+    def db_import_documents(dal_array)                                     #% import documents - populate main database table
                                                                        #% import into substantive database tables (tuple)
       begin
         @col[:tid]=@@id_t
         @en,@en_ast,@en_pls=[],[],[]
         @col[:en_a]=nil
         @col[:en_z]=nil
-        dbi_unit.each do |data|
+        dal_array.each do |data|
           #data.gsub!(/<[biu]>(.+?)<\/[biu]>/,'\1')                    # remove bold, italics, underscore
           data.gsub!(/<b>(.+?)<\/b>/,'\1')                             # remove bold, italics, underscore
           data.gsub!(/<i>(.+?)<\/i>/,'\1')                             # remove bold, italics, underscore
@@ -379,7 +405,7 @@ module SiSU_DB_import
               end
               if @en_pls[0]; @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last
               end
-              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt)
+              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt,@file)
               t.tuple
               case @col[:lev]
               when /1/; @col[:lv1]+=1
@@ -420,7 +446,7 @@ module SiSU_DB_import
               end
               if @en_pls[0]; @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last
               end
-              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt)
+              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt,@file)
               t.tuple
               @col[:lev]=@col[:plaintext]=@col[:body]=''
             elsif data[/^5~(?:~\S+)?(.+?)<~(\d+);((?:\w|[0-6]:)\d+);(\w\d+)><([0-9a-f]{#{@@dl}}):([0-9a-f]{#{@@dl}})>/]                             # header lev5 seg level
@@ -459,7 +485,7 @@ module SiSU_DB_import
               end
               if @en_pls[0]; @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last
               end
-              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt)
+              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt,@file)
               t.tuple
               @col[:lev]=@col[:plaintext]=@col[:body]=''
             elsif data[/^6~(?:~\S+)?(.+?)<~(\d+);((?:\w|[0-6]:)\d+);(\w\d+)><([0-9a-f]{#{@@dl}}):([0-9a-f]{#{@@dl}})>/] # header lev6 seg level
@@ -498,7 +524,7 @@ module SiSU_DB_import
               end
               if @en_pls[0]; @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last
               end
-              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt)
+              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt,@file)
               t.tuple
               @col[:lev]=@col[:plaintext]=@col[:body]=''
             else                                                               #% regular text
@@ -548,7 +574,7 @@ module SiSU_DB_import
               special_character_escape(@col[:body])
               @col[:plaintext]=@col[:body].dup
               strip_markup(@col[:plaintext])
-              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt)
+              t=SiSU_DB_tuple::Load_documents.new(@conn,@col,@opt,@file)
               t.tuple
               @en,@en_ast,@en_pls=[],[],[]
               @col[:en_a]=@col[:en_z]=nil
@@ -587,7 +613,7 @@ module SiSU_DB_import
                          :id_t => @@id_t,
                          :hash => digest_clean
                     }
-                    t=SiSU_DB_tuple::Load_endnotes.new(@conn,en)
+                    t=SiSU_DB_tuple::Load_endnotes.new(@conn,en,@opt,@file)
                     t.tuple
                   end
                 end
@@ -628,7 +654,7 @@ module SiSU_DB_import
                          :id_t => @@id_t,
                          :hash => digest_clean
                     }
-                    t=SiSU_DB_tuple::Load_endnotes.new(@conn,en)
+                    t=SiSU_DB_tuple::Load_endnotes.new(@conn,en,@opt,@file)
                     t.tuple
                   end
                 end
@@ -668,7 +694,7 @@ module SiSU_DB_import
                          :id_t => @@id_t,
                          :hash => digest_clean
                     }
-                    t=SiSU_DB_tuple::Load_endnotes.new(@conn,en)
+                    t=SiSU_DB_tuple::Load_endnotes.new(@conn,en,@opt,@file)
                     t.tuple
                   end
                 end
@@ -726,7 +752,7 @@ module SiSU_DB_import
       end
       self
     end
-    def import_db_urls(dbi_unit,meta)                                           #% import documents OID - populate database
+    def db_import_urls(dbi_unit,meta)                                           #% import documents OID - populate database
       begin
         @fnm=meta
         @env=SiSU_Env::Info_env.new(@opt.fns)
@@ -801,7 +827,7 @@ module SiSU_DB_import
         or (@opt.cmd=~/e/ and FileTest.file?("#{out}/#@fnb/#{@opt.fns}.tgz")==true)
           f[:sisupod],u[:sisupod]='sisupod,', "'#{base}/#@fnb/#{@opt.fns}.tgz',"
         end
-      t=SiSU_DB_tuple::Load_urls.new(@conn,f,u,@@id_t)
+      t=SiSU_DB_tuple::Load_urls.new(@conn,f,u,@@id_t,@opt,@file)
       t.tuple
       rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
