@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -57,8 +61,8 @@
 =end
 module SiSU_DB_remove
   class Remove
-    def initialize(opt,conn='' )
-      @opt,@conn=opt,conn
+    def initialize(opt,conn,file)
+      @opt,@conn,@file=opt,conn,file
       @md=SiSU_Param::Parameters.new(@opt).get
       @fnb=@md.fnb
       @db=SiSU_Env::Info_db.new
@@ -68,23 +72,18 @@ module SiSU_DB_remove
       if del
         del_id=del.join
         #@conn.execute("BEGIN")
-        @conn.execute(%{
-          DELETE FROM endnotes WHERE metadata_tid LIKE '#{del_id}';
-          DELETE FROM endnotes_asterisk WHERE metadata_tid LIKE '#{del_id}';
-          DELETE FROM endnotes_plus WHERE metadata_tid LIKE '#{del_id}';
-          DELETE FROM documents WHERE metadata_tid LIKE '#{del_id}';
-          DELETE FROM urls WHERE metadata_tid LIKE '#{del_id}';
-          DELETE FROM metadata WHERE tid LIKE '#{del_id}';
-          /*
-          DELETE FROM documents WHERE documents.metadata_tid LIKE '#{del_id}';
-          DELETE FROM endnotes WHERE endnotes.metadata_tid LIKE '#{del_id}';
-          DELETE FROM endnotes_asterisk WHERE endnotes_asterisk.metadata_tid LIKE '#{del_id}';
-          DELETE FROM endnotes_plus WHERE endnotes_plus.metadata_tid LIKE '#{del_id}';
-          DELETE FROM urls WHERE urls.metadata_tid LIKE '#{del_id}';
-          DELETE FROM metadata WHERE metadata.tid LIKE '#{del_id}';
-          */
-        })
-        #@conn.execute("COMMIT")
+        sql_entry=<<SQL
+DELETE FROM endnotes WHERE metadata_tid = '#{del_id}';
+DELETE FROM endnotes_asterisk WHERE metadata_tid = '#{del_id}';
+DELETE FROM endnotes_plus WHERE metadata_tid = '#{del_id}';
+DELETE FROM documents WHERE metadata_tid = '#{del_id}';
+DELETE FROM urls WHERE metadata_tid = '#{del_id}';
+DELETE FROM metadata WHERE tid = '#{del_id}';
+SQL
+        if @opt.cmd =~/M/
+          @file.puts sql_entry if @opt.cmd =~/M/
+        else @conn.execute(%{#{sql_entry}})
+        end
       else
         tell=SiSU_Screen::Ansi.new(@opt.cmd,"no such file in database #{@db.psql.db}::#{@opt.fns}")
         tell.puts_grey #if @opt.cmd.include? ?v
@@ -93,3 +92,17 @@ module SiSU_DB_remove
   end
 end
 __END__
+DELETE FROM endnotes WHERE metadata_tid = '#{del_id}';
+DELETE FROM endnotes_asterisk WHERE metadata_tid = '#{del_id}';
+DELETE FROM endnotes_plus WHERE metadata_tid = '#{del_id}';
+DELETE FROM documents WHERE metadata_tid = '#{del_id}';
+DELETE FROM urls WHERE metadata_tid = '#{del_id}';
+DELETE FROM metadata WHERE tid = '#{del_id}';
+/*
+DELETE FROM documents WHERE documents.metadata_tid = '#{del_id}';
+DELETE FROM endnotes WHERE endnotes.metadata_tid = '#{del_id}';
+DELETE FROM endnotes_asterisk WHERE endnotes_asterisk.metadata_tid = '#{del_id}';
+DELETE FROM endnotes_plus WHERE endnotes_plus.metadata_tid = '#{del_id}';
+DELETE FROM urls WHERE urls.metadata_tid = '#{del_id}';
+DELETE FROM metadata WHERE metadata.tid = '#{del_id}';
+*/
