@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -55,12 +59,8 @@
 
 =end
 module SiSU_Digest_view
-  require "#{SiSU_lib}/dal"
-  require "#{SiSU_lib}/sysenv"
+  require "#{SiSU_lib}/particulars"
   require "#{SiSU_lib}/i18n"
-  include SiSU_Env
-  include SiSU_Param
-  include SiSU_Viz
   pwd=Dir.pwd
   class Source
     @@dg=nil
@@ -70,11 +70,11 @@ module SiSU_Digest_view
       @@endnotes_para=[]
       @@dg=nil
       @dg=@@dg ||=SiSU_Env::Info_env.new.digest.type
-      @env=SiSU_Env::Info_env.new(@opt.fns)
+      @particulars=SiSU_Particulars::Combined_singleton.instance.get_all(opt)
     end
     def read
       begin
-        @md=SiSU_Param::Parameters.new(@opt).get
+        @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
         tool=if @opt.cmd =~/[MVv]/; "#{@env.program.text_editor} #{@env.path.output_tell}/#{@md.fnb}/#{@md.fn[:digest]}"
         else ''
         end
@@ -83,8 +83,7 @@ module SiSU_Digest_view
         tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.path.output_tell}/#{@md.fnb}/#{@md.fn[:digest]}")
         tell.flow if @opt.cmd =~/[MV]/
         my_make=SiSU_Env::Create_file.new(@opt.cmd,@opt.fns)
-        @dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
-        SiSU_Digest_view::Source::Scroll.new(@dal_array,@md).songsheet
+        SiSU_Digest_view::Source::Scroll.new(@particulars).songsheet
         SiSU_Env::Info_skin.new(@md).select
       rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
@@ -95,13 +94,13 @@ module SiSU_Digest_view
       @@dl=nil
       @@ds={}
       @@description,@@ds[:digests],@@ds[:tree],@@ds[:summary],@@sc_info=[],[],[],[],[]
-      def initialize(data='',md='')
-        @data,@md=data,md
+      def initialize(particulars) #data='',md='')
+        @particulars=particulars
+        @data,@env,@md=@particulars.dal_array,@particulars.env,@particulars.md
         SiSU_Env::SiSU_file.new(@md).mkdir
-        @@dg ||=SiSU_Env::Info_env.new.digest.type
-        @@dl ||=SiSU_Env::Info_env.new.digest.length
+        @@dg ||=@env.digest.type
+        @@dl ||=@env.digest.length
         @dg,@dl=@@dg,@@dl
-        @env=SiSU_Env::Info_env.new(@md.fns)
         l=SiSU_Env::Standardise_language.new.file_to_language(@md.fns)
         @language=l[:l]
         @tr=SiSU_Translate::Source.new(@md,@language)
@@ -136,7 +135,7 @@ module SiSU_Digest_view
       end
       def output
         filename_digest=SiSU_Env::SiSU_file.new(@md,@md.fn[:digest]).mkfile
-        filename_digest << @@description << @@ds[:digests] << @@ds[:tree] << @@ds[:summary] << @@sc_info
+        filename_digest << @@description.join << @@ds[:digests].join << @@ds[:tree].join << @@ds[:summary].join << @@sc_info.join
       end
       def rgx_txt(txt)
         txt=txt.gsub(/([()])/,"\\\\\\1")
