@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -56,34 +60,34 @@
 =end
 module SiSU_HTML
   require 'pstore'
+  require "#{SiSU_lib}/particulars"
+  include SiSU_Particulars
   require "#{SiSU_lib}/defaults"
+  include SiSU_Viz
   require "#{SiSU_lib}/html_table"
   require "#{SiSU_lib}/html_format_css"
+  include SiSU_HTML_Format_type
   require "#{SiSU_lib}/html_segments"
   require "#{SiSU_lib}/html_scroll"
-  require "#{SiSU_lib}/html_promo"
   include SiSU_HTML_seg
-  include SiSU_HTML_Format_type
+  require "#{SiSU_lib}/html_promo"
   include SiSU_HTML_promo
-  require "#{SiSU_lib}/param"
-  include SiSU_Param
-  include SiSU_Viz
   require "#{SiSU_lib}/html_tune"
   include SiSU_Tune
-  require "#{SiSU_lib}/dal"
   require "#{SiSU_lib}/shared_xml"
   class Source
     def initialize(opt)
       @opt=opt
+      @particulars=SiSU_Particulars::Combined_singleton.instance.get_all(opt)
     end
     def read
       songsheet
     end
     def songsheet
       begin
-        @md=SiSU_Param::Parameters.new(@opt).get
+        @md=@particulars.md
         @fnb=@md.fnb
-        @env=SiSU_Env::Info_env.new(@opt.fns)
+        @env=@particulars.env
         loc=@env.url.output_tell
         tool=if @opt.cmd =~/z/;   "#{@env.program.web_browser} #{loc}/#@fnb/#{@md.fn[:index]}"
         elsif @opt.cmd =~/[MVv]/; "#{@env.program.web_browser} #{loc}/#@fnb/#{@md.fn[:index]}"
@@ -95,7 +99,7 @@ module SiSU_HTML
         data=nil
         my_make=SiSU_Env::Create_file.new(@opt.cmd,@opt.fns,@md) #Beware #FIX opt and md, both not necessary
         SiSU_Env::SiSU_file.new(@md).mkdir
-        @tuned_file_array=SiSU_HTML::Source::Html_environment.new(@md).tuned_file_instructions
+        @tuned_file_array=SiSU_HTML::Source::Html_environment.new(@particulars).tuned_file_instructions
         data=@tuned_file_array
         scr_endnotes=SiSU_HTML::Source::Endnotes.new(data,@md).scroll
         toc=SiSU_HTML::Source::Toc.new(data,@md).songsheet
@@ -127,10 +131,11 @@ module SiSU_HTML
     end
     private
     class Html_environment
-      def initialize(md)
-        @md=md
+      def initialize(particulars)
+        @particulars=particulars
+        @md,@env=particulars.md,particulars.env
         @vz=SiSU_Env::Get_init.instance.skin
-        @env,@css,@symlnk=SiSU_Env::Info_env.new(@md.fns),SiSU_Style::CSS.new,SiSU_Env::Create_system_link.new #home
+        @env,@css,@symlnk=particulars.env,SiSU_Style::CSS.new,SiSU_Env::Create_system_link.new #home
       end
       def suffix_linkname #not used at present
         sfx=if @md.cmd =~/h/; '.html'
@@ -147,7 +152,6 @@ module SiSU_HTML
         SiSU_Env::SiSU_file.new(@md).mkdir
       end
       def tuned_file_instructions
-        @env=SiSU_Env::Info_env.new(@md.fns)
         @tell=SiSU_Screen::Ansi.new(@md.cmd)
         if @md
           @md.sfx=''
@@ -171,9 +175,8 @@ module SiSU_HTML
         my_make_source_file=SiSU_Env::Create_file.new(@md.cmd,@md.fns)
         @fnm=my_make_source_file.marshal_meta
         @tune_verse_marshal=my_make_source_file.marshal_tune
-        dal_array=SiSU_DAL::Source.new(@md).get # dal file drawn here
+        dal_array=@particulars.dal_array # dal file drawn here
         @tuned_file_array=SiSU_Tune::Tune.new(dal_array,@md).songsheet
-        require "#{SiSU_lib}/param"
         @tuned_file_array
       end
     end
@@ -253,7 +256,6 @@ module SiSU_HTML
       end
     end
     class Endnotes
-      include SiSU_Param
       include SiSU_HTML_Format_type
       def initialize(data,md)
         @data,@md=data,md
@@ -579,7 +581,6 @@ WOK
     class Scroll_head_and_segtoc < Toc
       def initialize(data,md='',toc='',links_guide_toc='')
         @data,@md,@toc,@links_guide_toc=data,md,toc,links_guide_toc
-        @env=SiSU_Env::Info_env.new(@md.fns)
         @vz=SiSU_Env::Get_init.instance.skin
       end
       def in_common
@@ -677,7 +678,6 @@ WOK
     class Seg < SiSU_HTML_seg::Seg
     end
     class Output
-      include SiSU_Param
       @@dp=nil
       def initialize(data='',md='')
         @data,@md=data,md
