@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -55,8 +59,6 @@
 
 =end
 module SiSU_HTML_Format
-  require "#{SiSU_lib}/param"
-  include SiSU_Param
   include SiSU_Viz
   class Paragraph_number
     def initialize(md,paranum)
@@ -143,7 +145,6 @@ module SiSU_HTML_Format
   class Head_information
     include SiSU_Viz
     include SiSU_HTML_Format
-    include SiSU_Env
     attr_reader :md,:sfx,:pdf,:rdf,:vz
     def initialize(md='')
       @md=md
@@ -977,7 +978,7 @@ WOK
       @format,parablock=txt[0],txt[1]
       @parablock=parablock
       ##performance hit does not justify action:
-      #@parablock=if parablock=~/\S+/ and parablock !~/<!Th?¡ /m
+      #@parablock=if parablock=~/\S+/ and parablock !~/<!Th?¡ /um
       #  wrap=SiSU_text_utils::Wrap.new(parablock,70,4)
       #  wrap.line_wrap
       #else parablock
