@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -98,8 +102,8 @@ module SiSU_HTML_table
       m=@parablock[/<!f(.+?)!>/,1]
       @@tablefoot << m if m
       @parablock.gsub!(/<!f.+?!>/,'')
-      @@tablehead=1 if @parablock =~/<!Th¡/
-      if @parablock =~/<!Th?¡.+?!~(\d+);\w\d+;\w\d+>/; @parablock=table_head($1)
+      @@tablehead=1 if @parablock =~/<!Th¡/u
+      if @parablock =~/<!Th?¡.+?!~(\d+);\w\d+;\w\d+>/u; @parablock=table_head($1)
       end
       if @parablock =~/<!TZ!>/
         tablefoot=[]
@@ -109,12 +113,12 @@ module SiSU_HTML_table
         end
       end
       if @@tablehead == 1
-        if @parablock =~/¡¡/
-          if @parablock =~/<!¡¡(\d+?)¡/
-            @parablock.gsub!(/<!¡¡(\d+?)¡/,table_row($1,true))
+        if @parablock =~/¡¡/u
+          if @parablock =~/<!¡¡(\d+?)¡/u
+            @parablock.gsub!(/<!¡¡(\d+?)¡/u,table_row($1,true))
           end
-          if @parablock =~/¡¡(\d+?)¡/
-            @parablock.gsub!(/¡¡(\d+?)¡/,table_cell($1,true))
+          if @parablock =~/¡¡(\d+?)¡/u
+            @parablock.gsub!(/¡¡(\d+?)¡/u,table_cell($1,true))
           end
           if @parablock =~/!>/
             @parablock.gsub!(/!>/,table_row_close(true))
@@ -123,11 +127,11 @@ module SiSU_HTML_table
         end
         @parablock
       else
-        if @parablock =~/<!¡¡(\d+?)¡/
-          @parablock.gsub!(/<!¡¡(\d+?)¡/,table_row($1))
+        if @parablock =~/<!¡¡(\d+?)¡/u
+          @parablock.gsub!(/<!¡¡(\d+?)¡/u,table_row($1))
         end
-        if @parablock =~/¡¡(\d+?)¡/
-          @parablock.gsub!(/¡¡(\d+?)¡/,table_cell($1))
+        if @parablock =~/¡¡(\d+?)¡/u
+          @parablock.gsub!(/¡¡(\d+?)¡/u,table_cell($1))
         end
         if @parablock =~/!>/
           @parablock.gsub!(/!>/,table_row_close)
