@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -56,9 +60,7 @@
 =end
 require "#{SiSU_lib}/param"
 module SiSU_Tune
-  #require "#{SiSU_lib}/defaults"
   require "#{SiSU_lib}/sysenv"
-  require "#{SiSU_lib}/param"
   require "#{SiSU_lib}/html_format" #watch
   include SiSU_Env
   include SiSU_Screen
@@ -85,7 +87,7 @@ module SiSU_Tune
       data=[]
       @data.each{|x| x.strip; data << x if not x.empty?} #1.9 array?
       data.each do |para|
-        @filename_tune.puts para, "\n" #if para !~/¡/
+        @filename_tune.puts para, "\n" #if para !~/¡/u
       end
     end
     def marshal
@@ -99,91 +101,91 @@ module SiSU_Tune
       @html=html
     end
     def clean
-      @html.gsub!(/¢/,'&cent;')    # &#162;
-      @html.gsub!(/£/,'&pound;')   # &#163;
-      @html.gsub!(/¥/,'&yen;')     # &#165;
-      @html.gsub!(/§/,'&sect;')    # &#167;
-      @html.gsub!(/©/,'&copy;')    # &#169;
-      @html.gsub!(/ª/,'&ordf;')    # &#170;
-      @html.gsub!(/«/,'&laquo;')   # &#171;
-      @html.gsub!(/®/,'&reg;')     # &#174;
-      @html.gsub!(/°/,'&deg;')     # &#176;
-      @html.gsub!(/±/,'&plusmn;')  # &#177;
-      @html.gsub!(/²/,'&sup2;')    # &#178;
-      @html.gsub!(/³/,'&sup3;')    # &#179;
-      @html.gsub!(/µ/,'&micro;')   # &#181;
-      @html.gsub!(/¶/,'&para;')    # &#182;
-      @html.gsub!(/¹/,'&sup1;')    # &#185;
-      @html.gsub!(/º/,'&ordm;')    # &#186;
-      @html.gsub!(/»/,'&raquo;')   # &#187;
-      @html.gsub!(/¼/,'&frac14;')  # &#188;
-      @html.gsub!(/½/,'&frac12;')  # &#189;
-      @html.gsub!(/¾/,'&frac34;')  # &#190;
-      @html.gsub!(/×/,'&times;')   # &#215;
-      @html.gsub!(/÷/,'&divide;')  # &#247;
-      @html.gsub!(/¿/,'&iquest;')  # &#191;
-      @html.gsub!(/À/,'&Agrave;')  # &#192;
-      @html.gsub!(/Á/,'&Aacute;')  # &#193;
-      @html.gsub!(/Â/,'&Acirc;')   # &#194;
-      @html.gsub!(/Ã/,'&Atilde;')  # &#195;
-      @html.gsub!(/Ä/,'&Auml;')    # &#196;
-      @html.gsub!(/Å/,'&Aring;')   # &#197;
-      @html.gsub!(/Æ/,'&AElig;')   # &#198;
-      @html.gsub!(/Ç/,'&Ccedil;')  # &#199;
-      @html.gsub!(/È/,'&Egrave;')  # &#200;
-      @html.gsub!(/É/,'&Eacute;')  # &#201;
-      @html.gsub!(/Ê/,'&Ecirc;')   # &#202;
-      @html.gsub!(/Ë/,'&Euml;')    # &#203;
-      @html.gsub!(/Ì/,'&Igrave;')  # &#204;
-      @html.gsub!(/Í/,'&Iacute;')  # &#205;
-      @html.gsub!(/Î/,'&Icirc;')   # &#206;
-      @html.gsub!(/Ï/,'&Iuml;')    # &#207;
-      @html.gsub!(/Ð/,'&ETH;')     # &#208;
-      @html.gsub!(/Ñ/,'&Ntilde;')  # &#209;
-      @html.gsub!(/Ò/,'&Ograve;')  # &#210;
-      @html.gsub!(/Ó/,'&Oacute;')  # &#211;
-      @html.gsub!(/Ô/,'&Ocirc;')   # &#212;
-      @html.gsub!(/Õ/,'&Otilde;')  # &#213;
-      @html.gsub!(/Ö/,'&Ouml;')    # &#214;
-      @html.gsub!(/Ø/,'&Oslash;')  # &#216;
-      @html.gsub!(/Ù/,'&Ugrave;')  # &#217;
-      @html.gsub!(/Ú/,'&Uacute;')  # &#218;
-      @html.gsub!(/Û/,'&Ucirc;')   # &#219;
-      @html.gsub!(/Ü/,'&Uuml;')    # &#220;
-      @html.gsub!(/Ý/,'&Yacute;')  # &#221;
-      @html.gsub!(/Þ/,'&THORN;')   # &#222;
-      @html.gsub!(/ß/,'&szlig;')   # &#223;
-      @html.gsub!(/à/,'&agrave;')  # &#224;
-      @html.gsub!(/á/,'&aacute;')  # &#225;
-      @html.gsub!(/â/,'&acirc;')   # &#226;
-      @html.gsub!(/ã/,'&atilde;')  # &#227;
-      @html.gsub!(/ä/,'&auml;')    # &#228;
-      @html.gsub!(/å/,'&aring;')   # &#229;
-      @html.gsub!(/æ/,'&aelig;')   # &#230;
-      @html.gsub!(/ç/,'&ccedil;')  # &#231;
-      @html.gsub!(/è/,'&egrave;')  # &#232;
-      @html.gsub!(/é/,'&eacute;')  # &#233;
-      @html.gsub!(/ê/,'&ecirc;')   # &#234;
-      @html.gsub!(/ë/,'&euml;')    # &#235;
-      @html.gsub!(/ì/,'&igrave;')  # &#236;
-      @html.gsub!(/í/,'&iacute;')  # &#237;
-      @html.gsub!(/î/,'&icirc;')   # &#238;
-      @html.gsub!(/ï/,'&iuml;')    # &#239;
-      @html.gsub!(/ð/,'&eth;')     # &#240;
-      @html.gsub!(/ñ/,'&ntilde;')  # &#241;
-      @html.gsub!(/ò/,'&ograve;')  # &#242;
-      @html.gsub!(/ó/,'&oacute;')  # &#243;
-      @html.gsub!(/ô/,'&ocirc;')   # &#244;
-      @html.gsub!(/õ/,'&otilde;')  # &#245;
-      @html.gsub!(/ö/,'&ouml;')    # &#246;
-      @html.gsub!(/ø/,'&oslash;')  # &#248;
-      @html.gsub!(/ù/,'&ugrave;')  # &#250;
-      @html.gsub!(/ú/,'&uacute;')  # &#251;
-      @html.gsub!(/û/,'&ucirc;')   # &#252;
-      @html.gsub!(/ü/,'&uuml;')    # &#253;
-      @html.gsub!(/þ/,'&thorn;')   # &#254;
-      @html.gsub!(/ÿ/,'&yuml;')    # &#255;
-      @html.gsub!(/ý/,'&yacute;')
+      @html.gsub!(/¢/u,'&cent;')    # &#162;
+      @html.gsub!(/£/u,'&pound;')   # &#163;
+      @html.gsub!(/¥/u,'&yen;')     # &#165;
+      @html.gsub!(/§/u,'&sect;')    # &#167;
+      @html.gsub!(/©/u,'&copy;')    # &#169;
+      @html.gsub!(/ª/u,'&ordf;')    # &#170;
+      @html.gsub!(/«/u,'&laquo;')   # &#171;
+      @html.gsub!(/®/u,'&reg;')     # &#174;
+      @html.gsub!(/°/u,'&deg;')     # &#176;
+      @html.gsub!(/±/u,'&plusmn;')  # &#177;
+      @html.gsub!(/²/u,'&sup2;')    # &#178;
+      @html.gsub!(/³/u,'&sup3;')    # &#179;
+      @html.gsub!(/µ/u,'&micro;')   # &#181;
+      @html.gsub!(/¶/u,'&para;')    # &#182;
+      @html.gsub!(/¹/u,'&sup1;')    # &#185;
+      @html.gsub!(/º/u,'&ordm;')    # &#186;
+      @html.gsub!(/»/u,'&raquo;')   # &#187;
+      @html.gsub!(/¼/u,'&frac14;')  # &#188;
+      @html.gsub!(/½/u,'&frac12;')  # &#189;
+      @html.gsub!(/¾/u,'&frac34;')  # &#190;
+      @html.gsub!(/×/u,'&times;')   # &#215;
+      @html.gsub!(/÷/u,'&divide;')  # &#247;
+      @html.gsub!(/¿/u,'&iquest;')  # &#191;
+      @html.gsub!(/À/u,'&Agrave;')  # &#192;
+      @html.gsub!(/Á/u,'&Aacute;')  # &#193;
+      @html.gsub!(/Â/u,'&Acirc;')   # &#194;
+      @html.gsub!(/Ã/u,'&Atilde;')  # &#195;
+      @html.gsub!(/Ä/u,'&Auml;')    # &#196;
+      @html.gsub!(/Å/u,'&Aring;')   # &#197;
+      @html.gsub!(/Æ/u,'&AElig;')   # &#198;
+      @html.gsub!(/Ç/u,'&Ccedil;')  # &#199;
+      @html.gsub!(/È/u,'&Egrave;')  # &#200;
+      @html.gsub!(/É/u,'&Eacute;')  # &#201;
+      @html.gsub!(/Ê/u,'&Ecirc;')   # &#202;
+      @html.gsub!(/Ë/u,'&Euml;')    # &#203;
+      @html.gsub!(/Ì/u,'&Igrave;')  # &#204;
+      @html.gsub!(/Í/u,'&Iacute;')  # &#205;
+      @html.gsub!(/Î/u,'&Icirc;')   # &#206;
+      @html.gsub!(/Ï/u,'&Iuml;')    # &#207;
+      @html.gsub!(/Ð/u,'&ETH;')     # &#208;
+      @html.gsub!(/Ñ/u,'&Ntilde;')  # &#209;
+      @html.gsub!(/Ò/u,'&Ograve;')  # &#210;
+      @html.gsub!(/Ó/u,'&Oacute;')  # &#211;
+      @html.gsub!(/Ô/u,'&Ocirc;')   # &#212;
+      @html.gsub!(/Õ/u,'&Otilde;')  # &#213;
+      @html.gsub!(/Ö/u,'&Ouml;')    # &#214;
+      @html.gsub!(/Ø/u,'&Oslash;')  # &#216;
+      @html.gsub!(/Ù/u,'&Ugrave;')  # &#217;
+      @html.gsub!(/Ú/u,'&Uacute;')  # &#218;
+      @html.gsub!(/Û/u,'&Ucirc;')   # &#219;
+      @html.gsub!(/Ü/u,'&Uuml;')    # &#220;
+      @html.gsub!(/Ý/u,'&Yacute;')  # &#221;
+      @html.gsub!(/Þ/u,'&THORN;')   # &#222;
+      @html.gsub!(/ß/u,'&szlig;')   # &#223;
+      @html.gsub!(/à/u,'&agrave;')  # &#224;
+      @html.gsub!(/á/u,'&aacute;')  # &#225;
+      @html.gsub!(/â/u,'&acirc;')   # &#226;
+      @html.gsub!(/ã/u,'&atilde;')  # &#227;
+      @html.gsub!(/ä/u,'&auml;')    # &#228;
+      @html.gsub!(/å/u,'&aring;')   # &#229;
+      @html.gsub!(/æ/u,'&aelig;')   # &#230;
+      @html.gsub!(/ç/u,'&ccedil;')  # &#231;
+      @html.gsub!(/è/u,'&egrave;')  # &#232;
+      @html.gsub!(/é/u,'&eacute;')  # &#233;
+      @html.gsub!(/ê/u,'&ecirc;')   # &#234;
+      @html.gsub!(/ë/u,'&euml;')    # &#235;
+      @html.gsub!(/ì/u,'&igrave;')  # &#236;
+      @html.gsub!(/í/u,'&iacute;')  # &#237;
+      @html.gsub!(/î/u,'&icirc;')   # &#238;
+      @html.gsub!(/ï/u,'&iuml;')    # &#239;
+      @html.gsub!(/ð/u,'&eth;')     # &#240;
+      @html.gsub!(/ñ/u,'&ntilde;')  # &#241;
+      @html.gsub!(/ò/u,'&ograve;')  # &#242;
+      @html.gsub!(/ó/u,'&oacute;')  # &#243;
+      @html.gsub!(/ô/u,'&ocirc;')   # &#244;
+      @html.gsub!(/õ/u,'&otilde;')  # &#245;
+      @html.gsub!(/ö/u,'&ouml;')    # &#246;
+      @html.gsub!(/ø/u,'&oslash;')  # &#248;
+      @html.gsub!(/ù/u,'&ugrave;')  # &#250;
+      @html.gsub!(/ú/u,'&uacute;')  # &#251;
+      @html.gsub!(/û/u,'&ucirc;')   # &#252;
+      @html.gsub!(/ü/u,'&uuml;')    # &#253;
+      @html.gsub!(/þ/u,'&thorn;')   # &#254;
+      @html.gsub!(/ÿ/u,'&yuml;')    # &#255;
+      @html.gsub!(/ý/u,'&yacute;')
       @html
     end
   end
