@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -59,40 +63,6 @@ module SiSU
   require "#{SiSU_lib}/sysenv"
   include SiSU_Screen
   @@pwd=Dir.pwd
-  class Remote_download
-    def initialize(requested_file)
-      @requested_file=requested_file
-    end
-    def pod
-      re_p_div=/http:\/\/([^\/]+)(\/\S+?)\/(sisupod(?:\.zip)?|[^\/]+?\.ssp)$/
-      re_p=/(sisupod(?:\.zip)?|[^\/]+?\.ssp)$/
-      if @requested_file =~ re_p_div
-        @site,@pth,@pod= re_p_div.match(@requested_file).captures
-      elsif @requested_file =~ re_p
-        @pod= re_p.match(@requested_file).captures
-      end
-      def site
-        @site
-      end
-      def path
-        @pth
-      end
-      def dir_stub
-        re_p_stub=/.+?([^\/]+)$/
-        pod_stub= re_p_stub.match(path).captures.join if path
-      end
-      def name_source
-        @pod
-      end
-      def name
-        pod_download_as=if name_source=~/(?:sisupod\.(?:zip|ssp))/
-          dir_stub + '.ssp'
-        else name_source
-        end
-      end
-      self
-    end
-  end
   class Op
     @@env=SiSU_Env::Info_env.new
     def initialize(opt,req,message)
@@ -123,8 +93,9 @@ module SiSU
       if not @opt.files.empty?
         @opt.files.each do |fns|
           env=SiSU_Env::Info_env.new(fns)
-          if fns =~ /(?:sisupod(?:\.zip)?|\.ssp)$/
-            pod_name=Remote_download.new(fns).pod.name
+          if fns =~ /sisupod(?:\.zip)?|\S+?(?:\.ss[mt]\.zip|\.ssp)$/
+            require "#{SiSU_lib}/remote" #check
+            pod_name=SiSU_Remote::Remote_download.new(fns).pod.name
             tell=SiSU_Screen::Ansi.new(@opt.cmd,pod_name)
             tell.puts_blue unless @opt.cmd =~/q/
             @opt.files.shift
@@ -160,7 +131,8 @@ module SiSU
                   when /^source_kdissert$/; SiSU_Kdi_source::Source.new(@opt).read      ## -S
                   when /^digests$/;         SiSU_Digest_view::Source.new(@opt).read     # -N
                   when /^xml_scaffold$/;    SiSU_XML_scaffold::Source.new(@opt).read    # -T
-                  when /^plaintext$/;       SiSU_Plaintext::Source.new(@opt).read       # -a -A -e -E -f
+                  #when /^air$/;             SiSU_Air::Source.new(@opt).read             # -A
+                  when /^plaintext$/;       SiSU_Plaintext::Source.new(@opt).read       # -a
                   when /^wikispeak$/;       SiSU_Wikispeak::Source.new(@opt).read       # -g
                   when /^odf$/;             SiSU_ODF::Source.new(@opt).read             # -o
                   when /^xml_md_oai_pmh_dc$/; SiSU_XML_metadata::OAI_PMH.new(@opt).read # -O
@@ -306,7 +278,7 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
       if @opt.mod.inspect =~/--convert|--to|--from/
         require "#{SiSU_lib}/sst_convert_markup"
       end
-      if @opt.cmd =~/([abCcDdFfgGHhIiJjLMmNnOopQqrRSsTtUuVvwWXxYyZ_0-9])/ \
+      if @opt.cmd =~/([AabCcDdFfgGHhIiJjLMmNnOopQqrRSsTtUuVvwWXxYyZ_0-9])/ \
       and @opt.cmd =~/^-/ \
       and @opt.mod.inspect !~/--(?:sitemaps|query|identify)/ \
       or @opt.mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/ #and
@@ -357,7 +329,7 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
           path[:xsd]=path[:xml] + '/rnc'
           path[:xsd]=path[:xml] + '/rng'
           #path_dtd="#{@@env.path.output}/_sisu/xml/dtd"
-          re_p=/(sisupod(?:\.zip)?|[^\/]+?\.ssp)$/
+          re_p=/(sisupod(?:\.zip)?|\S+?\.ss[mt]\.zip|[^\/]+?\.ssp)$/
           unless @opt.files.join(',') =~ re_p #do not mix pods with source markup files in command line
             unless ( FileTest.directory?(path[:css]) \
             and FileTest.directory?(path[:xsd]) )
@@ -406,8 +378,8 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
             path_image='./_sisu/processing/external_document/image'
             path_skin='./_sisu/processing/external_document/skin/doc'
             @get_s,@get_p=[],[]
-            re_s=/((?:https?|file):\/\/\S+?\.sst)/
-            re_p=/((?:https?|file):\/\/\S+?(?:\/sisupod(?:\.zip)?|\.ssp))/
+            re_s=/((?:https?|file):\/\/\S+?\.sst)$/
+            re_p=/((?:https?|file):\/\/\S+?(?:\/\S+?\.ss[mt]\.zip|sisupod(?:\.zip)?|\.ssp))/
             @opt.files.each do |fns|
               if fns =~re_s
                 @get_s << re_s.match(fns)[1] if re_s
@@ -431,7 +403,7 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
             retry unless @retry_count > 1
           ensure
           end
-          @opt.files=@opt.files.collect {|x| x=x.gsub(/(?:https?|file):\/\/\S+\/(\S+)\.sst/,'\1.-sst') }
+          @opt.files=@opt.files.collect {|x| x=x.gsub(/(?:https?|file):\/\/\S+\/(\S+)\.sst$/,'\1.-sst') }
         end
         if @opt.cmd=~/m/               #% -m dal
           op('dal','dal')
@@ -447,6 +419,8 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
         end
         if @opt.cmd =~/[hHz]/; op('html','html')               #% -h -H -z html css
         end
+        if @opt.cmd =~/A/; op('air','air')         #% #-A
+        end
         if @opt.cmd =~/a/; op('plaintext','plaintext')         #% -a #-A -f -e -E plaintext -a creates ms-dos type; -A creates unix type, plaintext file
         end
         if @opt.cmd =~/g/; op('wikispeak','wikispeak')         #% -g wiki
@@ -554,7 +528,7 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
       @opt.files.each do |fns|
         if FileTest.file?(fns)
           @opt.fns=fns
-          unless @opt.fns =~ /(?:\.(?:(?:-|ssm\.)?sst|ssm|ssp|sx[sdn]\.xml|termsheet.rb)|sisupod(?:\.zip)?)$/
+          unless @opt.fns =~ /(?:\.(?:(?:-|ssm\.)?sst|ssm|ssp|sx[sdn]\.xml|termsheet.rb)|\S+?\.ss[mt]\.zip|sisupod(?:\.zip)?|\S+?\.ssp)$/
             if @opt.fns=~/\.kdi$/ \
             and @opt.mod.inspect =~/--(?:convert(?:-from)?|from)[=-]kdi/
             elsif @opt.fns=~/\.sx[sdn]\.xml$/ \
@@ -576,8 +550,11 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
     end
   end
   begin                                                              #% select what to do
-    require 'jcode'
-    $KCODE='UTF8'
+    if RUBY_VERSION  < '1.9'
+      require 'jcode'
+      $KCODE='UTF8'
+    end
+    require "#{SiSU_lib}/constants"
     require "#{SiSU_lib}/options"
     require "#{SiSU_lib}/sysenv"
     include SiSU_Env
