@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -308,7 +312,7 @@ WOK
         table_message='[table omitted, see other document formats]'
         fix=[]
         data.each do |para|
-          para.gsub!(/<!Th?¡.+/m,"#@br#{table_message}")
+          para.gsub!(/<!Th?¡.+/um,"#@br#{table_message}")
           para.gsub!(/.+?<-#>/,'')                                           # remove dummy headings (used by html) #check
           para.gsub!(/_\*\s+/,'* ')                                          # bullet markup, marked down
           para.gsub!(/<sup>(.+?)<\/sup>/,'^\1^')
@@ -446,7 +450,7 @@ WOK
               #formatMono=MonoSiSU.new('<br /><a name="owner.details">Owner Details</a>')
               #@@manpage[:owner_details]=formatMono.bold_para
               #para=''
-            elsif para =~/(¡|<!Th?)/ #tables !
+            elsif para =~/(¡|<!Th?)/u #tables !
             elsif para =~/(.*)<!#!>(.*)/
               one,two=$1,$2
               format_text=Format_text_object.new(one,two)
