@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -73,28 +77,54 @@ module SiSU_Markup_type
         or @cont[0] =~ /^(?:%\s+)?sisu-([0-9](?:\.[0-9]+){1,2})/
           @version_declared=$1
         end
-        @flag_57,@flag_38=false,false
+        @flat_66,@flag_57,@flag_38=false,false,false
         @cont.each_with_index do |y,i|
-          if @flag_57 \
-          or y =~/^:?A~\?? @title/
-            @version_determined=0.57
-            @flag_57=true
-            break
+          if y =~/^(?:0\{?~links?|@links?:)\s/
+            links=unless y =~/\{.+?\}\S+/; oldlinks=' (pre 0.20.4 header links)'
+            else ' (post 0.20.4 header links)'
+            end
           end
-          if @flag_38 \
-          or y =~/^:?A~/
-            @version_determined=0.38
-            @flag_38=true
-            break if i >= 200
-            if y =~ /(?:~{\*+|~\[\*|~\[\+)\s/
-              @version_determined=0.42 #0.38 can safely be treated as 0.42
+          unless @flag_38
+            if y =~/^:?A~/
+              version='0.38'
+              @version_determined=version
+              @flag_38=true
+            end
+          end
+          if @flag_38
+            if @flag_66 \
+            or y =~/[:;]\{.+?\}[:;][a-z+]/
+              version='0.66'
+              @version_determined=version
+              @flag_66=true
               break
             end
           end
-          if y =~/^0~/ \
-          and not @flag_38
-            @version_determined=0.16
-            break
+        end
+        @flag_57,@flag_38=false,false
+        unless @flag_66
+          @cont.each_with_index do |y,i|
+            if @flag_57 \
+            or y =~/^:?A~\?? @title/
+              @version_determined=0.57
+              @flag_57=true
+              break
+            end
+            if @flag_38 \
+            or y =~/^:?A~/
+              @version_determined=0.38
+              @flag_38=true
+              break if i >= 200
+              if y =~ /(?:~{\*+|~\[\*|~\[\+)\s/
+                @version_determined=0.42 #0.38 can safely be treated as 0.42
+                break
+              end
+            end
+            if y =~/^0~/ \
+            and not @flag_38
+              @version_determined=0.16
+              break
+            end
           end
         end
         @@fns=@opt.fns
