@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -191,7 +195,7 @@ GSUB
         m=parablock[/<!f(.+?)!>/,1]
         @@tablefoot<<m if m
         parablock.gsub!(/<!f.+?!>/,'')
-        @@tablehead=1 if parablock =~/<!Th¡/
+        @@tablehead=1 if parablock =~/<!Th¡/u
         parablock.gsub!(/<!Th?¡.+?!~(\d+)>/,
            #%{<table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center"><tr><td valign="top" align="justify"><p class="norm" id="\\1">  </p> </td><td>\n} +
            %{<table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">})
@@ -204,12 +208,12 @@ GSUB
             #%{#{tablefoot}})
         end
         if @@tablehead == 1
-          if parablock =~/¡¡/
-            parablock.gsub!(/<!¡¡(\d+?)¡/,
+          if parablock =~/¡¡/u
+            parablock.gsub!(/<!¡¡(\d+?)¡/u,
               %{\n<tr>} +
               %{\n<td width="\\1%" valign="top">} +
               %{#{para_table}<b>})
-            parablock.gsub!(/¡¡(\d+?)¡/,
+            parablock.gsub!(/¡¡(\d+?)¡/u,
               %{</b></td><td width="\\1%" valign="top">} +
               %{#{para_table}<b>})
             parablock.gsub!(/!>/, '</b></td></tr>')
@@ -217,11 +221,11 @@ GSUB
           end
           parablock
         else
-          parablock.gsub!(/<!¡¡(\d+?)¡/,
+          parablock.gsub!(/<!¡¡(\d+?)¡/u,
             %{\n<tr>} +
             %{\n<td width="\\1%" valign="top">} +
             %{#{para_table}})
-          parablock.gsub!(/¡¡(\d+?)¡/,
+          parablock.gsub!(/¡¡(\d+?)¡/u,
             %{</td><td width="\\1%" valign="top">} +
             %{#{para_table}})
           parablock.gsub!(/!>/, '</td></tr>')
