@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -151,10 +155,55 @@ module SiSU_XML_munge
   class Trans
     require "#{SiSU_lib}/defaults"
     def initialize(md)
+      @md=md
       @sys=SiSU_Env::System_call.new
-      @dir=SiSU_Env::Info_env.new(md.fns)
+      @dir=SiSU_Env::Info_env.new(@md.fns)
       @dp=SiSU_Env::Info_env.new.digest.pattern
       @url_brace=SiSU_Viz::Skin.new.url_decoration
+      if @md.sem_tag
+        #@ab ||=SiSU_Viz::Skin.new.semantic_tags.default
+        @ab ||=semantic_tags.default
+      end
+    end
+    def semantic_tags
+      def default
+        {
+          :pub =>     'publication',
+          :conv =>    'convention',
+          :vol =>     'volume',
+          :pg =>      'page',
+          :cty =>     'city',
+          :org =>     'organization',
+          :uni =>     'university',
+          :dept =>    'department',
+          :fac =>     'faculty',
+          :inst =>    'institute',
+          :co =>      'company',
+          :com =>     'company',
+          :conv =>    'convention',
+          :dt =>      'date',
+          :y =>       'year',
+          :m =>       'month',
+          :d =>       'day',
+          :ti =>      'title',
+          :au =>      'author',
+          :ed =>      'editor', #editor?
+          :v =>       'version', #edition
+          :n =>       'name',
+          :fn =>      'firstname',
+          :mn =>      'middlename',
+          :ln =>      'lastname',
+          :in =>      'initials',
+          :qt =>      'quote',
+          :ct =>      'cite',
+          :ref =>     'reference',
+          :ab =>      'abreviation',
+          :def =>     'define',
+          :desc =>    'description',
+          :trans =>   'translate',
+        }
+      end
+      self
     end
     def char_enc #character encode
       def utf8(para='')
@@ -163,178 +212,178 @@ module SiSU_XML_munge
           #¢£¥§©ª«®°±²³µ¶¹º»¼½¾×÷
           ##para.gsub!(//, '&#;')
           ##para.gsub!(//, '&;')
-          para.gsub!(/¢/, '&#162;') # '&cent;'   # &#162;
-          para.gsub!(/£/, '&#163;') # '&pound;'  # &#163;
-          para.gsub!(/¥/, '&#165;') # '&yen;'    # &#165;
-          para.gsub!(/§/, '&#167;') # '&sect;'   # &#167;
-          para.gsub!(/©/, '&#169;') # '&copy;'   # &#169;
-          para.gsub!(/ª/, '&#170;') # '&ordf;'   # &#170;
-          para.gsub!(/«/, '&#171;') # '&laquo;'  # &#171;
-          para.gsub!(/®/, '&#174;') # '&reg;'    # &#174;
-          para.gsub!(/°/, '&#176;') # '&deg;'    # &#176;
-          para.gsub!(/±/, '&#177;') # '&plusmn;' # &#177;
-          para.gsub!(/²/, '&#178;') # '&sup2;'   # &#178;
-          para.gsub!(/³/, '&#179;') # '&sup3;'   # &#179;
-          para.gsub!(/µ/, '&#181;') # '&micro;'  # &#181;
-          para.gsub!(/¶/, '&#182;') # '&para;'   # &#182;
-          para.gsub!(/¹/, '&#185;') # '&sup1;'   # &#185;
-          para.gsub!(/º/, '&#186;') # '&ordm;'   # &#186;
-          para.gsub!(/»/, '&#187;') # '&raquo;'  # &#187;
-          para.gsub!(/¼/, '&#188;') # '&frac14;' # &#188;
-          para.gsub!(/½/, '&#189;') # '&frac12;' # &#189;
-          para.gsub!(/¾/, '&#190;') # '&frac34;' # &#190;
-          para.gsub!(/×/, '&#215;') # '&times;'  # &#215;
-          para.gsub!(/÷/, '&#247;') # '&divide;' # &#247;
-          para.gsub!(/¿/, '&#191;') # '&iquest;' # &#191;
-          para.gsub!(/À/, '&#192;') # '&Agrave;' # &#192;
-          para.gsub!(/Á/, '&#193;') # '&Aacute;' # &#193;
-          para.gsub!(/Â/, '&#194;') # '&Acirc;'  # &#194;
-          para.gsub!(/Ã/, '&#195;') # '&Atilde;' # &#195;
-          para.gsub!(/Ä/, '&#196;') # '&Auml;'   # &#196;
-          para.gsub!(/Å/, '&#197;') # '&Aring;'  # &#197;
-          para.gsub!(/Æ/, '&#198;') # '&AElig;'  # &#198;
-          para.gsub!(/Ç/, '&#199;') # '&Ccedil;' # &#199;
-          para.gsub!(/È/, '&#200;') # '&Egrave;' # &#200;
-          para.gsub!(/É/, '&#201;') # '&Eacute;' # &#201;
-          para.gsub!(/Ê/, '&#202;') # '&Ecirc;'  # &#202;
-          para.gsub!(/Ë/, '&#203;') # '&Euml;'   # &#203;
-          para.gsub!(/Ì/, '&#204;') # '&Igrave;' # &#204;
-          para.gsub!(/Í/, '&#205;') # '&Iacute;' # &#205;
-          para.gsub!(/Î/, '&#206;') # '&Icirc;'  # &#206;
-          para.gsub!(/Ï/, '&#207;') # '&Iuml;'   # &#207;
-          para.gsub!(/Ð/, '&#208;') # '&ETH;'    # &#208;
-          para.gsub!(/Ñ/, '&#209;') # '&Ntilde;' # &#209;
-          para.gsub!(/Ò/, '&#210;') # '&Ograve;' # &#210;
-          para.gsub!(/Ó/, '&#211;') # '&Oacute;' # &#211;
-          para.gsub!(/Ô/, '&#212;') # '&Ocirc;'  # &#212;
-          para.gsub!(/Õ/, '&#213;') # '&Otilde;' # &#213;
-          para.gsub!(/Ö/, '&#214;') # '&Ouml;'   # &#214;
-          para.gsub!(/Ø/, '&#216;') # '&Oslash;' # &#216;
-          para.gsub!(/Ù/, '&#217;') # '&Ugrave;' # &#217;
-          para.gsub!(/Ú/, '&#218;') # '&Uacute;' # &#218;
-          para.gsub!(/Û/, '&#219;') # '&Ucirc;'  # &#219;
-          para.gsub!(/Ü/, '&#220;') # '&Uuml;'   # &#220;
-          para.gsub!(/Ý/, '&#221;') # '&Yacute;' # &#221;
-          para.gsub!(/Þ/, '&#222;') # '&THORN;'  # &#222;
-          para.gsub!(/ß/, '&#223;') # '&szlig;'  # &#223;
-          para.gsub!(/à/, '&#224;') # '&agrave;' # &#224;
-          para.gsub!(/á/, '&#225;') # '&aacute;' # &#225;
-          para.gsub!(/â/, '&#226;') # '&acirc;'  # &#226;
-          para.gsub!(/ã/, '&#227;') # '&atilde;' # &#227;
-          para.gsub!(/ä/, '&#228;') # '&auml;'   # &#228;
-          para.gsub!(/å/, '&#229;') # '&aring;'  # &#229;
-          para.gsub!(/æ/, '&#230;') # '&aelig;'  # &#230;
-          para.gsub!(/ç/, '&#231;') # '&ccedil;' # &#231;
-          para.gsub!(/è/, '&#232;') # '&egrave;' # &#232;
-          para.gsub!(/é/, '&#233;') # '&acute;'  # &#233;
-          para.gsub!(/ê/, '&#234;') # '&circ;'   # &#234;
-          para.gsub!(/ë/, '&#235;') # '&euml;'   # &#235;
-          para.gsub!(/ì/, '&#236;') # '&igrave;' # &#236;
-          para.gsub!(/í/, '&#237;') # '&acute;'  # &#237;
-          para.gsub!(/î/, '&#238;') # '&icirc;'  # &#238;
-          para.gsub!(/ï/, '&#239;') # '&iuml;'   # &#239;
-          para.gsub!(/ð/, '&#240;') # '&eth;'    # &#240;
-          para.gsub!(/ñ/, '&#241;') # '&ntilde;' # &#241;
-          para.gsub!(/ò/, '&#242;') # '&ograve;' # &#242;
-          para.gsub!(/ó/, '&#243;') # '&oacute;' # &#243;
-          para.gsub!(/ô/, '&#244;') # '&ocirc;'  # &#244;
-          para.gsub!(/õ/, '&#245;') # '&otilde;' # &#245;
-          para.gsub!(/ö/, '&#246;') # '&ouml;'   # &#246;
-          para.gsub!(/ø/, '&#248;') # '&oslash;' # &#248;
-          para.gsub!(/ù/, '&#250;') # '&ugrave;' # &#250;
-          para.gsub!(/ú/, '&#251;') # '&uacute;' # &#251;
-          para.gsub!(/û/, '&#252;') # '&ucirc;'  # &#252;
-          para.gsub!(/ü/, '&#253;') # '&uuml;'   # &#253;
-          para.gsub!(/þ/, '&#254;') # '&thorn;'  # &#254;
-          para.gsub!(/ÿ/, '&#255;') # '&yuml;'   # &#255;
+          para.gsub!(/¢/u, '&#162;') # '&cent;'   # &#162;
+          para.gsub!(/£/u, '&#163;') # '&pound;'  # &#163;
+          para.gsub!(/¥/u, '&#165;') # '&yen;'    # &#165;
+          para.gsub!(/§/u, '&#167;') # '&sect;'   # &#167;
+          para.gsub!(/©/u, '&#169;') # '&copy;'   # &#169;
+          para.gsub!(/ª/u, '&#170;') # '&ordf;'   # &#170;
+          para.gsub!(/«/u, '&#171;') # '&laquo;'  # &#171;
+          para.gsub!(/®/u, '&#174;') # '&reg;'    # &#174;
+          para.gsub!(/°/u, '&#176;') # '&deg;'    # &#176;
+          para.gsub!(/±/u, '&#177;') # '&plusmn;' # &#177;
+          para.gsub!(/²/u, '&#178;') # '&sup2;'   # &#178;
+          para.gsub!(/³/u, '&#179;') # '&sup3;'   # &#179;
+          para.gsub!(/µ/u, '&#181;') # '&micro;'  # &#181;
+          para.gsub!(/¶/u, '&#182;') # '&para;'   # &#182;
+          para.gsub!(/¹/u, '&#185;') # '&sup1;'   # &#185;
+          para.gsub!(/º/u, '&#186;') # '&ordm;'   # &#186;
+          para.gsub!(/»/u, '&#187;') # '&raquo;'  # &#187;
+          para.gsub!(/¼/u, '&#188;') # '&frac14;' # &#188;
+          para.gsub!(/½/u, '&#189;') # '&frac12;' # &#189;
+          para.gsub!(/¾/u, '&#190;') # '&frac34;' # &#190;
+          para.gsub!(/×/u, '&#215;') # '&times;'  # &#215;
+          para.gsub!(/÷/u, '&#247;') # '&divide;' # &#247;
+          para.gsub!(/¿/u, '&#191;') # '&iquest;' # &#191;
+          para.gsub!(/À/u, '&#192;') # '&Agrave;' # &#192;
+          para.gsub!(/Á/u, '&#193;') # '&Aacute;' # &#193;
+          para.gsub!(/Â/u, '&#194;') # '&Acirc;'  # &#194;
+          para.gsub!(/Ã/u, '&#195;') # '&Atilde;' # &#195;
+          para.gsub!(/Ä/u, '&#196;') # '&Auml;'   # &#196;
+          para.gsub!(/Å/u, '&#197;') # '&Aring;'  # &#197;
+          para.gsub!(/Æ/u, '&#198;') # '&AElig;'  # &#198;
+          para.gsub!(/Ç/u, '&#199;') # '&Ccedil;' # &#199;
+          para.gsub!(/È/u, '&#200;') # '&Egrave;' # &#200;
+          para.gsub!(/É/u, '&#201;') # '&Eacute;' # &#201;
+          para.gsub!(/Ê/u, '&#202;') # '&Ecirc;'  # &#202;
+          para.gsub!(/Ë/u, '&#203;') # '&Euml;'   # &#203;
+          para.gsub!(/Ì/u, '&#204;') # '&Igrave;' # &#204;
+          para.gsub!(/Í/u, '&#205;') # '&Iacute;' # &#205;
+          para.gsub!(/Î/u, '&#206;') # '&Icirc;'  # &#206;
+          para.gsub!(/Ï/u, '&#207;') # '&Iuml;'   # &#207;
+          para.gsub!(/Ð/u, '&#208;') # '&ETH;'    # &#208;
+          para.gsub!(/Ñ/u, '&#209;') # '&Ntilde;' # &#209;
+          para.gsub!(/Ò/u, '&#210;') # '&Ograve;' # &#210;
+          para.gsub!(/Ó/u, '&#211;') # '&Oacute;' # &#211;
+          para.gsub!(/Ô/u, '&#212;') # '&Ocirc;'  # &#212;
+          para.gsub!(/Õ/u, '&#213;') # '&Otilde;' # &#213;
+          para.gsub!(/Ö/u, '&#214;') # '&Ouml;'   # &#214;
+          para.gsub!(/Ø/u, '&#216;') # '&Oslash;' # &#216;
+          para.gsub!(/Ù/u, '&#217;') # '&Ugrave;' # &#217;
+          para.gsub!(/Ú/u, '&#218;') # '&Uacute;' # &#218;
+          para.gsub!(/Û/u, '&#219;') # '&Ucirc;'  # &#219;
+          para.gsub!(/Ü/u, '&#220;') # '&Uuml;'   # &#220;
+          para.gsub!(/Ý/u, '&#221;') # '&Yacute;' # &#221;
+          para.gsub!(/Þ/u, '&#222;') # '&THORN;'  # &#222;
+          para.gsub!(/ß/u, '&#223;') # '&szlig;'  # &#223;
+          para.gsub!(/à/u, '&#224;') # '&agrave;' # &#224;
+          para.gsub!(/á/u, '&#225;') # '&aacute;' # &#225;
+          para.gsub!(/â/u, '&#226;') # '&acirc;'  # &#226;
+          para.gsub!(/ã/u, '&#227;') # '&atilde;' # &#227;
+          para.gsub!(/ä/u, '&#228;') # '&auml;'   # &#228;
+          para.gsub!(/å/u, '&#229;') # '&aring;'  # &#229;
+          para.gsub!(/æ/u, '&#230;') # '&aelig;'  # &#230;
+          para.gsub!(/ç/u, '&#231;') # '&ccedil;' # &#231;
+          para.gsub!(/è/u, '&#232;') # '&egrave;' # &#232;
+          para.gsub!(/é/u, '&#233;') # '&acute;'  # &#233;
+          para.gsub!(/ê/u, '&#234;') # '&circ;'   # &#234;
+          para.gsub!(/ë/u, '&#235;') # '&euml;'   # &#235;
+          para.gsub!(/ì/u, '&#236;') # '&igrave;' # &#236;
+          para.gsub!(/í/u, '&#237;') # '&acute;'  # &#237;
+          para.gsub!(/î/u, '&#238;') # '&icirc;'  # &#238;
+          para.gsub!(/ï/u, '&#239;') # '&iuml;'   # &#239;
+          para.gsub!(/ð/u, '&#240;') # '&eth;'    # &#240;
+          para.gsub!(/ñ/u, '&#241;') # '&ntilde;' # &#241;
+          para.gsub!(/ò/u, '&#242;') # '&ograve;' # &#242;
+          para.gsub!(/ó/u, '&#243;') # '&oacute;' # &#243;
+          para.gsub!(/ô/u, '&#244;') # '&ocirc;'  # &#244;
+          para.gsub!(/õ/u, '&#245;') # '&otilde;' # &#245;
+          para.gsub!(/ö/u, '&#246;') # '&ouml;'   # &#246;
+          para.gsub!(/ø/u, '&#248;') # '&oslash;' # &#248;
+          para.gsub!(/ù/u, '&#250;') # '&ugrave;' # &#250;
+          para.gsub!(/ú/u, '&#251;') # '&uacute;' # &#251;
+          para.gsub!(/û/u, '&#252;') # '&ucirc;'  # &#252;
+          para.gsub!(/ü/u, '&#253;') # '&uuml;'   # &#253;
+          para.gsub!(/þ/u, '&#254;') # '&thorn;'  # &#254;
+          para.gsub!(/ÿ/u, '&#255;') # '&yuml;'   # &#255;
         end
       end
       def html(para='')
         if @sys.locale =~/utf-?8/i # instead ucs for utf8 #require 'iconv' ? Iñtërnâtiônàlizætiøn
-          para.gsub!(/¢/, '&cent;')      # &#162;
-          para.gsub!(/£/, '&pound;')     # &#163;
-          para.gsub!(/¥/, '&yen;')       # &#165;
-          para.gsub!(/§/, '&sect;')      # &#167;
-          para.gsub!(/©/, '&copy;')      # &#169;
-          para.gsub!(/ª/, '&ordf;')      # &#170;
-          para.gsub!(/«/, '&laquo;')     # &#171;
-          para.gsub!(/®/, '&reg;')       # &#174;
-          para.gsub!(/°/, '&deg;')       # &#176;
-          para.gsub!(/±/, '&plusmn;')    # &#177;
-          para.gsub!(/²/, '&sup2;')      # &#178;
-          para.gsub!(/³/, '&sup3;')      # &#179;
-          para.gsub!(/µ/, '&micro;')     # &#181;
-          para.gsub!(/¶/, '&para;')      # &#182;
-          para.gsub!(/¹/, '&sup1;')      # &#185;
-          para.gsub!(/º/, '&ordm;')      # &#186;
-          para.gsub!(/»/, '&raquo;')     # &#187;
-          para.gsub!(/¼/, '&frac14;')    # &#188;
-          para.gsub!(/½/, '&frac12;')    # &#189;
-          para.gsub!(/¾/, '&frac34;')    # &#190;
-          para.gsub!(/×/, '&times;')     # &#215;
-          para.gsub!(/÷/, '&divide;')    # &#247;
-          para.gsub!(/¿/, '&iquest;')    # &#191;
-          para.gsub!(/À/, '&Agrave;')    # &#192;
-          para.gsub!(/Á/, '&Aacute;')    # &#193;
-          para.gsub!(/Â/, '&Acirc;')     # &#194;
-          para.gsub!(/Ã/, '&Atilde;')    # &#195;
-          para.gsub!(/Ä/, '&Auml;')      # &#196;
-          para.gsub!(/Å/, '&Aring;')     # &#197;
-          para.gsub!(/Æ/, '&AElig;')     # &#198;
-          para.gsub!(/Ç/, '&Ccedil;')    # &#199;
-          para.gsub!(/È/, '&Egrave;')    # &#200;
-          para.gsub!(/É/, '&Eacute;')    # &#201;
-          para.gsub!(/Ê/, '&Ecirc;')     # &#202;
-          para.gsub!(/Ë/, '&Euml;')      # &#203;
-          para.gsub!(/Ì/, '&Igrave;')    # &#204;
-          para.gsub!(/Í/, '&Iacute;')    # &#205;
-          para.gsub!(/Î/, '&Icirc;')     # &#206;
-          para.gsub!(/Ï/, '&Iuml;')      # &#207;
-          para.gsub!(/Ð/, '&ETH;')       # &#208;
-          para.gsub!(/Ñ/, '&Ntilde;')    # &#209;
-          para.gsub!(/Ò/, '&Ograve;')    # &#210;
-          para.gsub!(/Ó/, '&Oacute;')    # &#211;
-          para.gsub!(/Ô/, '&Ocirc;')     # &#212;
-          para.gsub!(/Õ/, '&Otilde;')    # &#213;
-          para.gsub!(/Ö/, '&Ouml;')      # &#214;
-          para.gsub!(/Ø/, '&Oslash;')    # &#216;
-          para.gsub!(/Ù/, '&Ugrave;')    # &#217;
-          para.gsub!(/Ú/, '&Uacute;')    # &#218;
-          para.gsub!(/Û/, '&Ucirc;')     # &#219;
-          para.gsub!(/Ü/, '&Uuml;')      # &#220;
-          para.gsub!(/Ý/, '&Yacute;')    # &#221;
-          para.gsub!(/Þ/, '&THORN;')     # &#222;
-          para.gsub!(/ß/, '&szlig;')     # &#223;
-          para.gsub!(/à/, '&agrave;')    # &#224;
-          para.gsub!(/á/, '&aacute;')    # &#225;
-          para.gsub!(/â/, '&acirc;')     # &#226;
-          para.gsub!(/ã/, '&atilde;')    # &#227;
-          para.gsub!(/ä/, '&auml;')      # &#228;
-          para.gsub!(/å/, '&aring;')     # &#229;
-          para.gsub!(/æ/, '&aelig;')     # &#230;
-          para.gsub!(/ç/, '&ccedil;')    # &#231;
-          para.gsub!(/è/, '&egrave;')    # &#232;
-          para.gsub!(/é/, '&acute;')     # &#233;
-          para.gsub!(/ê/, '&circ;')      # &#234;
-          para.gsub!(/ë/, '&euml;')      # &#235;
-          para.gsub!(/ì/, '&igrave;')    # &#236;
-          para.gsub!(/í/, '&acute;')     # &#237;
-          para.gsub!(/î/, '&icirc;')     # &#238;
-          para.gsub!(/ï/, '&iuml;')      # &#239;
-          para.gsub!(/ð/, '&eth;')       # &#240;
-          para.gsub!(/ñ/, '&ntilde;')    # &#241;
-          para.gsub!(/ò/, '&ograve;')    # &#242;
-          para.gsub!(/ó/, '&oacute;')    # &#243;
-          para.gsub!(/ô/, '&ocirc;')     # &#244;
-          para.gsub!(/õ/, '&otilde;')    # &#245;
-          para.gsub!(/ö/, '&ouml;')      # &#246;
-          para.gsub!(/ø/, '&oslash;')    # &#248;
-          para.gsub!(/ù/, '&ugrave;')    # &#250;
-          para.gsub!(/ú/, '&uacute;')    # &#251;
-          para.gsub!(/û/, '&ucirc;')     # &#252;
-          para.gsub!(/ü/, '&uuml;')      # &#253;
-          para.gsub!(/þ/, '&thorn;')     # &#254;
-          para.gsub!(/ÿ/, '&yuml;')      # &#255;
+          para.gsub!(/¢/u, '&cent;')      # &#162;
+          para.gsub!(/£/u, '&pound;')     # &#163;
+          para.gsub!(/¥/u, '&yen;')       # &#165;
+          para.gsub!(/§/u, '&sect;')      # &#167;
+          para.gsub!(/©/u, '&copy;')      # &#169;
+          para.gsub!(/ª/u, '&ordf;')      # &#170;
+          para.gsub!(/«/u, '&laquo;')     # &#171;
+          para.gsub!(/®/u, '&reg;')       # &#174;
+          para.gsub!(/°/u, '&deg;')       # &#176;
+          para.gsub!(/±/u, '&plusmn;')    # &#177;
+          para.gsub!(/²/u, '&sup2;')      # &#178;
+          para.gsub!(/³/u, '&sup3;')      # &#179;
+          para.gsub!(/µ/u, '&micro;')     # &#181;
+          para.gsub!(/¶/u, '&para;')      # &#182;
+          para.gsub!(/¹/u, '&sup1;')      # &#185;
+          para.gsub!(/º/u, '&ordm;')      # &#186;
+          para.gsub!(/»/u, '&raquo;')     # &#187;
+          para.gsub!(/¼/u, '&frac14;')    # &#188;
+          para.gsub!(/½/u, '&frac12;')    # &#189;
+          para.gsub!(/¾/u, '&frac34;')    # &#190;
+          para.gsub!(/×/u, '&times;')     # &#215;
+          para.gsub!(/÷/u, '&divide;')    # &#247;
+          para.gsub!(/¿/u, '&iquest;')    # &#191;
+          para.gsub!(/À/u, '&Agrave;')    # &#192;
+          para.gsub!(/Á/u, '&Aacute;')    # &#193;
+          para.gsub!(/Â/u, '&Acirc;')     # &#194;
+          para.gsub!(/Ã/u, '&Atilde;')    # &#195;
+          para.gsub!(/Ä/u, '&Auml;')      # &#196;
+          para.gsub!(/Å/u, '&Aring;')     # &#197;
+          para.gsub!(/Æ/u, '&AElig;')     # &#198;
+          para.gsub!(/Ç/u, '&Ccedil;')    # &#199;
+          para.gsub!(/È/u, '&Egrave;')    # &#200;
+          para.gsub!(/É/u, '&Eacute;')    # &#201;
+          para.gsub!(/Ê/u, '&Ecirc;')     # &#202;
+          para.gsub!(/Ë/u, '&Euml;')      # &#203;
+          para.gsub!(/Ì/u, '&Igrave;')    # &#204;
+          para.gsub!(/Í/u, '&Iacute;')    # &#205;
+          para.gsub!(/Î/u, '&Icirc;')     # &#206;
+          para.gsub!(/Ï/u, '&Iuml;')      # &#207;
+          para.gsub!(/Ð/u, '&ETH;')       # &#208;
+          para.gsub!(/Ñ/u, '&Ntilde;')    # &#209;
+          para.gsub!(/Ò/u, '&Ograve;')    # &#210;
+          para.gsub!(/Ó/u, '&Oacute;')    # &#211;
+          para.gsub!(/Ô/u, '&Ocirc;')     # &#212;
+          para.gsub!(/Õ/u, '&Otilde;')    # &#213;
+          para.gsub!(/Ö/u, '&Ouml;')      # &#214;
+          para.gsub!(/Ø/u, '&Oslash;')    # &#216;
+          para.gsub!(/Ù/u, '&Ugrave;')    # &#217;
+          para.gsub!(/Ú/u, '&Uacute;')    # &#218;
+          para.gsub!(/Û/u, '&Ucirc;')     # &#219;
+          para.gsub!(/Ü/u, '&Uuml;')      # &#220;
+          para.gsub!(/Ý/u, '&Yacute;')    # &#221;
+          para.gsub!(/Þ/u, '&THORN;')     # &#222;
+          para.gsub!(/ß/u, '&szlig;')     # &#223;
+          para.gsub!(/à/u, '&agrave;')    # &#224;
+          para.gsub!(/á/u, '&aacute;')    # &#225;
+          para.gsub!(/â/u, '&acirc;')     # &#226;
+          para.gsub!(/ã/u, '&atilde;')    # &#227;
+          para.gsub!(/ä/u, '&auml;')      # &#228;
+          para.gsub!(/å/u, '&aring;')     # &#229;
+          para.gsub!(/æ/u, '&aelig;')     # &#230;
+          para.gsub!(/ç/u, '&ccedil;')    # &#231;
+          para.gsub!(/è/u, '&egrave;')    # &#232;
+          para.gsub!(/é/u, '&acute;')     # &#233;
+          para.gsub!(/ê/u, '&circ;')      # &#234;
+          para.gsub!(/ë/u, '&euml;')      # &#235;
+          para.gsub!(/ì/u, '&igrave;')    # &#236;
+          para.gsub!(/í/u, '&acute;')     # &#237;
+          para.gsub!(/î/u, '&icirc;')     # &#238;
+          para.gsub!(/ï/u, '&iuml;')      # &#239;
+          para.gsub!(/ð/u, '&eth;')       # &#240;
+          para.gsub!(/ñ/u, '&ntilde;')    # &#241;
+          para.gsub!(/ò/u, '&ograve;')    # &#242;
+          para.gsub!(/ó/u, '&oacute;')    # &#243;
+          para.gsub!(/ô/u, '&ocirc;')     # &#244;
+          para.gsub!(/õ/u, '&otilde;')    # &#245;
+          para.gsub!(/ö/u, '&ouml;')      # &#246;
+          para.gsub!(/ø/u, '&oslash;')    # &#248;
+          para.gsub!(/ù/u, '&ugrave;')    # &#250;
+          para.gsub!(/ú/u, '&uacute;')    # &#251;
+          para.gsub!(/û/u, '&ucirc;')     # &#252;
+          para.gsub!(/ü/u, '&uuml;')      # &#253;
+          para.gsub!(/þ/u, '&thorn;')     # &#254;
+          para.gsub!(/ÿ/u, '&yuml;')      # &#255;
         end
       end
       self
@@ -345,10 +394,8 @@ module SiSU_XML_munge
       end
     end
     def markup(para='')
-      #if para !~/^<:code>/
-        wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
-        para=tidywords(wordlist).join(' ').strip
-      #end
+      wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
+      para=tidywords(wordlist).join(' ').strip
       para.gsub!(/(^|\s+)<\s+/,'\1&lt; '); para.gsub!(/\s+>(\s+|$)/,' &gt;\1')
       para.gsub!(/<:pb>\s*/,'')
       para.gsub!(/<+[-~]#>+/,'')
@@ -423,6 +470,61 @@ module SiSU_XML_munge
       para.gsub!(/&lt;(\/?en)&gt;/,'<\1>')
       para
     end
+    def xml_sem_block_paired(matched) # colon depth: many, recurs
+      matched.gsub!(/\b(au):\{(.+?)\}:\1\b/m,   %{<sem:#{@ab[:au]} depth="many">\\2</sem:#{@ab[:au]}>}) # sem :
+      matched.gsub!(/\b(vol):\{(.+?)\}:\1\b/m, %{<sem:#{@ab[:vol]} depth="many">\\2</sem:#{@ab[:vol]}>}) # sem :
+      matched.gsub!(/\b(pub):\{(.+?)\}:\1\b/m, %{<sem:#{@ab[:pub]} depth="many">\\2</sem:#{@ab[:pub]}>}) # sem :
+      matched.gsub!(/\b(ref):\{(.+?)\}:\1\b/m, %{<sem:#{@ab[:ref]} depth="many">\\2</sem:#{@ab[:ref]}>}) # sem :
+      matched.gsub!(/\b(desc):\{(.+?)\}:\1\b/m,%{<sem:#{@ab[:desc]} depth="many">\\2</sem:#{@ab[:desc]}>}) # sem :
+      matched.gsub!(/\b(conv):\{(.+?)\}:\1\b/m,%{<sem:#{@ab[:conv]} depth="many">\\2</sem:#{@ab[:conv]}>}) # sem :
+      matched.gsub!(/\b(ct):\{(.+?)\}:\1\b/m,  %{<sem:#{@ab[:ct]} depth="many">\\2</sem:#{@ab[:ct]}>}) # sem :
+      matched.gsub!(/\b(cty):\{(.+?)\}:\1\b/m, %{<sem:#{@ab[:cty]} depth="many">\\2</sem:#{@ab[:cty]}>}) # sem :
+      matched.gsub!(/\b(org):\{(.+?)\}:\1\b/m, %{<sem:#{@ab[:org]} depth="many">\\2</sem:#{@ab[:org]}>}) # sem :
+      matched.gsub!(/\b(dt):\{(.+?)\}:\1\b/m,   %{<sem:#{@ab[:dt]} depth="many">\\2</sem:#{@ab[:dt]}>}) # sem :
+      matched.gsub!(/\b(n):\{(.+?)\}:\1\b/m,   %{<sem:#{@ab[:n]} depth="many">\\2</sem:#{@ab[:n]}>}) # sem :
+      matched.gsub!(/([a-z]+(?:[_:.][a-z]+)*)(?::\{(.+?)\}:\1)/m,'<sem:\1 depth="many">\2</sem:\1>') # sem :
+    end
+    def xml_semantic_tags(para)
+      if @md.sem_tag
+        para.gsub!(/([a-z]+(?:[_:.][a-z]+)*)(?::\{(.+?)\}:\1)/m) {|c| xml_sem_block_paired(c) } # sem :
+        para.gsub!(/([a-z]+(?:[_:.][a-z]+)*)(?::\{(.+?)\}:\1)/m) {|c| xml_sem_block_paired(c) } # sem :
+        para.gsub!(/([a-z]+(?:[_:.][a-z]+)*)(?::\{(.+?)\}:\1)/m) {|c| xml_sem_block_paired(c) } # sem :
+        #colon one / single / flat / shallow
+        para.gsub!(/:\{(.+?)\}:au\b/m,             %{<sem:#{@ab[:au]} depth="one">\\1</sem:#{@ab[:au]}>}) # sem :
+        para.gsub!(/:\{(.+?)\}:n\b/m,              %{<sem:#{@ab[:n]} depth="one">\\1</sem:#{@ab[:n]}>}) # sem :
+        para.gsub!(/:\{(.+?)\}:ti\b/m,             %{<sem:#{@ab[:ti]} depth="one">\\1</sem:#{@ab[:ti]}>}) # sem :
+        para.gsub!(/:\{(.+?)\}:ref\b/m,            %{<sem:#{@ab[:ref]} depth="one">\\1</sem:#{@ab[:ref]}>}) # sem :
+        para.gsub!(/:\{(.+?)\}:desc\b/m,           %{<sem:#{@ab[:desc]} depth="one">\\1</sem:#{@ab[:desc]}>}) # sem :
+        para.gsub!(/:\{(.+?)\}:cty\b/m,            %{<sem:#{@ab[:cty]} depth="one">\\1</sem:#{@ab[:cty]}>}) # sem :
+        para.gsub!(/:\{(.+?)\}:org\b/m,            %{<sem:#{@ab[:org]} depth="one">\\1</sem:#{@ab[:org]}>}) # sem :
+        para.gsub!(/:\{(.+?)\}:([a-z]+(?:[_:.][a-z]+)*)/m,'<sem:\2 depth="one">\1</sem:\2>') # sem :
+        #semicolon zero / none
+        para.gsub!(/;\{([^}]+(?![;]))\};ti\b/m,    %{<sem:#{@ab[:ti]} depth="zero">\\1</sem:#{@ab[:ti]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};qt\b/m,    %{<sem:#{@ab[:qt]} depth="zero">\\1</sem:#{@ab[:qt]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};ref\b/m,   %{<sem:#{@ab[:ref]} depth="zero">\\1</sem:#{@ab[:ref]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};ed\b/m,    %{<sem:#{@ab[:ed]} depth="zero">\\1</sem:#{@ab[:ed]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};v\b/m,     %{<sem:#{@ab[:v]} depth="zero">\\1</sem:#{@ab[:v]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};desc\b/m,  %{<sem:#{@ab[:desc]} depth="zero">\\1</sem:#{@ab[:desc]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};def\b/m,   %{<sem:#{@ab[:def]} depth="zero">\\1</sem:#{@ab[:def]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};trans\b/m, %{<sem:#{@ab[:trans]} depth="zero">\\1</sem:#{@ab[:trans]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};y\b/m,     %{<sem:#{@ab[:y]} depth="zero">\\1</sem:#{@ab[:y]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};ab\b/m,    %{<sem:#{@ab[:ab]} depth="zero">\\1</sem:#{@ab[:ab]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};pg\b/m,    %{<sem:#{@ab[:pg]} depth="zero">\\1</sem:#{@ab[:pg]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};fn?\b/m,   %{<sem:#{@ab[:fn]} depth="zero">\\1</sem:#{@ab[:fn]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};mn?\b/m,   %{<sem:#{@ab[:mn]} depth="zero">\\1</sem:#{@ab[:mn]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};ln?\b/m,   %{<sem:#{@ab[:ln]} depth="zero">\\1</sem:#{@ab[:ln]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};in\b/m,    %{<sem:#{@ab[:in]} depth="zero">\\1</sem:#{@ab[:in]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};uni\b/m,   %{<sem:#{@ab[:uni]} depth="zero">\\1</sem:#{@ab[:uni]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};fac\b/m,   %{<sem:#{@ab[:fac]} depth="zero">\\1</sem:#{@ab[:fac]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};inst\b/m,  %{<sem:#{@ab[:inst]} depth="zero">\\1</sem:#{@ab[:inst]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};dept\b/m,  %{<sem:#{@ab[:dpt]} depth="zero">\\1</sem:#{@ab[:dept]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};org\b/m,   %{<sem:#{@ab[:org]} depth="zero">\\1</sem:#{@ab[:org]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};com?\b/m,  %{<sem:#{@ab[:com]} depth="zero">\\1</sem:#{@ab[:com]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};cty\b/m,   %{<sem:#{@ab[:cty]} depth="zero">\\1</sem:#{@ab[:cty]}>}) # sem ;
+        para.gsub!(/;\{([^}]+(?![;]))\};([a-z]+(?:[_:.][a-z]+)*)/m,'<sem:\2 depth="zero">\1</sem:\2>') # sem ;
+      end
+      para
+    end
   end
 end
 module SiSU_XML_tags #Format
@@ -438,7 +540,8 @@ module SiSU_XML_tags #Format
       @rdfurl=%{  rdf:about="http://www.jus.uio.no/lm/toc"\n}
       if @md.dc_title                                                            # DublinCore 1 - title
         @rdf_title=%{    dc.title="#{seg_name}#{@md.dc_title}"\n}
-        @dc_title=%{  <meta name="dc.title" content="#{seg_name}#{@md.dc_title}" />\n}
+        @dc_title=%{  <meta name="dc.title" content="#{@md.dc_title}" />\n}
+        #@dc_title=%{  <meta name="dc.title" content="#{seg_name}#{@md.dc_title}" />\n}
       end
       if @md.dc_creator                                                          # DublinCore 2 - creator/author (author)
         @rdf_creator=%{    dc.creator="#{@md.dc_creator}"\n}
