@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -110,7 +114,7 @@ WOK
         or cont[0] =~ /^(?:%\s+)?sisu-([0-9](?:\.[0-9]+){1,2})/
           @declared_markup=$1
         end
-        @flag_57,@flag_38=false,false
+        @flat_66,@flag_57,@flag_38=false,false,false
         cont.each_with_index do |y,i|
           if y =~/^(?:0\{?~links?|@links?:)\s/ \
           and f =~/(?:\.sst|\.ssm|\.ssi|\.s[123])/
@@ -118,55 +122,81 @@ WOK
             else ' (post 0.20.4 header links)'
             end
           end
-          if @flag_57 \
-          or y =~/^:?A~\?? @title/
-            version='0.57'
-            markup=Markup_inform.new(version,'0.57' + oldlinks,@declared_markup,@declared_type)
-            @flag_57=true
-            break
+          unless @flag_38
+            if (y =~/^:?A~/ and f =~/(?:\.sst|\.ssm|\.ssi)/)
+              version='0.38'
+              markup=Markup_inform.new(version,'0.38' + oldlinks,@declared_markup,@declared_type)
+              @flag_38=true
+            end
           end
-          if @flag_38 \
-          or (y =~/^:?A~/ and f =~/(?:\.sst|\.ssm|\.ssi)/)
-            version='0.38'
-            markup=Markup_inform.new(version,'0.38' + oldlinks,@declared_markup,@declared_type)
-            @flag_38=true
-            break if i >= 200
-            if y =~ /(?:~{\*+|~\[\*|~\[\+)\s/
-              version='0.42'
-              markup=Markup_inform.new(version,'0.42' + oldlinks,@declared_markup,@declared_type)
+          if @flag_38
+            if @flag_66 \
+            or y =~/[a-z+][:;]\{.+?\}[:;][a-z+]/
+              version='0.66'
+              markup=Markup_inform.new(version,'0.66' + oldlinks,@declared_markup,@declared_type)
+              @flag_66=true
               break
             end
           end
-          if (y =~/^1~/ and f =~/(?:\.sst|\.ssm|\.ssi)/) \
-          and not @flag_38
-            version='0.37'
-            markup=Markup_inform.new(version,'0.37 is substantially 0.16 - 0.36 markup with new file-extension' + oldlinks,@declared_markup,@declared_type)
-            break
-          end
-          if y =~/^1~/ \
-          and f =~/\.([rs])([123])/ \
-          and not @flag_38
-            t,n=$1,$2
-            version='0.16'
-            instruct=if t =~/r/
-              " (change file extension from .#{t}#{n} to .ssm)"
-            else " (change file extension from .#{t}#{n} to .sst)"
+        end
+        unless @flag_66
+          cont.each_with_index do |y,i|
+            if y =~/^(?:0\{?~links?|@links?:)\s/ \
+            and f =~/(?:\.sst|\.ssm|\.ssi|\.s[123])/
+              links=unless y =~/\{.+?\}\S+/; oldlinks=' (pre 0.20.4 header links)'
+              else ' (post 0.20.4 header links)'
+              end
             end
-            markup=Markup_inform.new(version,'0.16 - 0.36' + instruct + links,@declared_markup,@declared_type)
-            break
+            if @flag_57 \
+            or (y =~/^:?A~\?? @title/ and f =~/(?:\.sst|\.ssm|\.ssi)/)
+              version='0.57'
+              markup=Markup_inform.new(version,'0.57' + oldlinks,@declared_markup,@declared_type)
+              @flag_57=true
+              break
+            end
+            if @flag_38 \
+            or (y =~/^:?A~/ and f =~/(?:\.sst|\.ssm|\.ssi)/)
+              version='0.38'
+              markup=Markup_inform.new(version,'0.38' + oldlinks,@declared_markup,@declared_type)
+              @flag_38=true
+              break if i >= 200
+              if y =~ /(?:~{\*+|~\[\*|~\[\+)\s/
+                version='0.42'
+                markup=Markup_inform.new(version,'0.42' + oldlinks,@declared_markup,@declared_type)
+                break
+              end
+            end
+            if (y =~/^1~/ and f =~/(?:\.sst|\.ssm|\.ssi)/) \
+            and not @flag_38
+              version='0.37'
+              markup=Markup_inform.new(version,'0.37 is substantially 0.16 - 0.36 markup with new file-extension' + oldlinks,@declared_markup,@declared_type)
+              break
+            end
+            if y =~/^1~/ \
+            and f =~/\.([rs])([123])/ \
+            and not @flag_38
+              t,n=$1,$2
+              version='0.16'
+              instruct=if t =~/r/
+                " (change file extension from .#{t}#{n} to .ssm)"
+              else " (change file extension from .#{t}#{n} to .sst)"
+              end
+              markup=Markup_inform.new(version,'0.16 - 0.36' + instruct + links,@declared_markup,@declared_type)
+              break
+            end
+            if y =~/^0\{~/ \
+            and not @flag_38
+              version='0.1'
+              markup=Markup_inform.new(version,'0.1 - 0.15',@declared_markup,@declared_type)
+              break
+            end
+            if y =~/^0\{{3}/ \
+            and not @flag_38
+              markup=Markup_inform.new('circa. 1997','old, check date',@declared_markup,@declared_type)
+              break
+            end
+            markup='Not a recognised file type '
           end
-          if y =~/^0\{~/ \
-          and not @flag_38
-            version='0.1'
-            markup=Markup_inform.new(version,'0.1 - 0.15',@declared_markup,@declared_type)
-            break
-          end
-          if y =~/^0\{{3}/ \
-          and not @flag_38
-            markup=Markup_inform.new('circa. 1997','old, check date',@declared_markup,@declared_type)
-            break
-          end
-          markup='Not a recognised file type '
         end
         markup
       else Markup_history.new(@opt).help_query
@@ -215,6 +245,22 @@ WOK
     def initialize(opt)
       @opt=opt
     end
+    def sisu_0_66
+      <<WOK
+  SiSU 0.66 same as previous, adds semantic tags
+    /[:;]\{.+?\}[:;][a-z+]/
+    e.g. :{ Ralph last;{Amissah};last }:author
+
+WOK
+    end
+    def sisu_0_65
+      <<WOK
+  SiSU 0.65 same as previous, adds semantic tags
+    /[a-z+][:;]\{.+?\}[:;][a-z+]/
+    e.g. author:{ Ralph last;{Amissah};last }:author
+
+WOK
+    end
     def sisu_0_57
       <<WOK
   SiSU 0.57 is the same as 0.42 with the introduction of some a shortcut to use
@@ -329,7 +375,11 @@ WOK
       tell=if @opt.mod.inspect =~/--query/
         tell=case @opt.mod.inspect
         when /history/
-          "#{sisu_0_57}#{sisu_0_42}#{sisu_0_38}\n#{sisu_0_37}\n#{sisu_0_16}\n#{sisu_0_1}"
+          "#{sisu_0_66}#{sisu_0_57}#{sisu_0_42}#{sisu_0_38}\n#{sisu_0_37}\n#{sisu_0_16}\n#{sisu_0_1}"
+        when /0.66/
+          "#{sisu_0_66}#{sisu_0_57}#{sisu_0_42}#{sisu_0_38}#{sisu_0_16}"
+        when /0.65/
+          "#{sisu_0_65}#{sisu_0_57}#{sisu_0_42}#{sisu_0_38}#{sisu_0_16}"
         when /0.57/
           "#{sisu_0_57}#{sisu_0_42}#{sisu_0_38}#{sisu_0_16}"
         when /0.42/
