@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -55,14 +59,15 @@
 
 =end
 module SiSU_simple_xml_model_dom
+  require "#{SiSU_lib}/particulars"
+  include SiSU_Particulars
   require "#{SiSU_lib}/defaults"
-  require "#{SiSU_lib}/param"
-  include SiSU_Param
   include SiSU_Viz
   require "#{SiSU_lib}/sysenv"
   include SiSU_Env
   require "#{SiSU_lib}/dal_doc_str"
   require "#{SiSU_lib}/shared_xml"
+  require "#{SiSU_lib}/shared_sem"
   require "#{SiSU_lib}/xml_format"
   include SiSU_XML_format
   include SiSU_XML_munge
@@ -74,11 +79,11 @@ module SiSU_simple_xml_model_dom
     @@fns=nil
     def initialize(opt)
       @opt=opt
+      @particulars=SiSU_Particulars::Combined_singleton.instance.get_env_md(opt)
     end
     def read
       begin
-        @md=SiSU_Param::Parameters.new(@opt).get #bug, relies on info persistence, assumes -m has previously been run
-        @env=SiSU_Env::Info_env.new(@opt.fns)
+        @env,@md=@particulars.env,@particulars.md #bug, md relies on info persistence, assumes -m has previously been run
         path=@env.path.output_tell
         loc=@env.url.output_tell
         tool=if @opt.cmd =~/[MV]/; "#{Dir.pwd}/#{@md.fn[:sxd]}\n\t#{@env.program.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:sxd]}"
@@ -90,12 +95,12 @@ module SiSU_simple_xml_model_dom
         tell.flow if @opt.cmd =~/[MV]/
         unless @@fns==@opt.fns
           @@fns=@opt.fns
-          @@dal_array=[]
+          @@fns_array=[]
         end
-        @dal_array=if @@dal_array.empty?; read_fnm
-        else @@dal_array.dup # check
+        @fns_array=if @@fns_array.empty?; read_fnm
+        else @@fns_array.dup # check
         end
-        SiSU_simple_xml_model_dom::Convert::Songsheet.new(@dal_array,@md,@env).songsheet
+        SiSU_simple_xml_model_dom::Convert::Songsheet.new(@fns_array,@particulars).songsheet
       rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure #file closed in songsheet
       end
@@ -109,12 +114,12 @@ module SiSU_simple_xml_model_dom
     end
     private
     class Songsheet
-      def initialize(data,md,dir)
-        @data,@md,@env=data,md,dir
+      def initialize(data,particulars)
+        @data,@particulars,@env,@md=data,particulars,particulars.env,particulars.md
       end
       def songsheet
         begin
-          SiSU_simple_xml_model_dom::Convert::Scroll.new(@data,@md).songsheet
+          SiSU_simple_xml_model_dom::Convert::Scroll.new(@data,@particulars).songsheet
           SiSU_simple_xml_model_dom::Convert::Tidy.new(@md,@env).xml if @md.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@md.fn[:sxd]).xml if @md.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
         rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
@@ -127,13 +132,12 @@ module SiSU_simple_xml_model_dom
       require "#{SiSU_lib}/css"
       include SiSU_text_utils
       @@xml={ :body=>[],:open=>[],:close=>[],:head=>[] }
-      def initialize(data='',md=nil)
-        @data,@md=data,md
+      def initialize(data='',particulars='')
+        @data,@env,@md=data,particulars.env,particulars.md
         @vz=SiSU_Env::Get_init.instance.skin
         @regx=/^(?:(?:<:p[bn]>\s*)?(?::?[A-C]|\d~)(?:(\S+))?\s+)?(.+)/
         @tab="\t"
         if @md
-          @env=SiSU_Env::Info_env.new(@md.fns)
           @trans=SiSU_XML_munge::Trans.new(@md)
         end
         @sys=SiSU_Env::System_call.new
@@ -157,7 +161,7 @@ module SiSU_simple_xml_model_dom
         para.gsub!(/~\{([*+]+)\s+(.+?)\}~/,
           '<endnote><symbol>\1</symbol><note>\2</note></endnote> ')
         para.gsub!(/~\{(.+?)\}~/,
-          '<endnote><note>\2</note></endnote> ')
+          '<endnote><note>\1</note></endnote> ')
       end
       def xml_head(meta)
         txt=meta.text
@@ -352,6 +356,7 @@ WOK
         (0..6).each { |x| @cont[x]=@level[x]=false }
         (4..6).each { |x| @xml_contents_close[x]='' }
         data.each do |para|
+          #para=SiSU_sem::Tags.new(para,@md).rm.all
           wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
           para=tidywords(wordlist).join(' ').strip
           para.gsub!(/<[-~]#>/,'')
@@ -532,19 +537,26 @@ WOK
         content << @@xml[:open] << @@xml[:head] << @@xml[:body] << @@xml[:metadata]
         content << @@xml[:owner_details] if @md.stmp =~/\w\w/
         content << @@xml[:tail] << @@xml[:close]
-        Output.new(content.to_s,@md).xml
+        Output.new(content.join,@md).xml
         @@xml={}
       end
     end
     class Output
-      include SiSU_Param
-      include SiSU_Env
       def initialize(data,md)
         @data,@md=data,md
+        @trans=SiSU_XML_munge::Trans.new(@md)
       end
       def xml
         @sisu=[]
         @data.each do |para|
+          if para !~/^\s*(?:%+ |<:code>)/
+            if @md.sem_tag and para =~/[:;]\{|\}[:;]/
+              para=@trans.xml_semantic_tags(para)
+            end
+            if para =~/[:;]\{|\}[:;]/
+              para=SiSU_sem::Tags.new(para,@md).rm.all
+            end
+          end
           para.gsub!(/\/\{(.+?)\}\//,'<italic>\1</italic>')
           para.gsub!(/\*\{(.+?)\}\*/,'<bold>\1</bold>')
           para.gsub!(/!\{(.+?)\}!/,'<bold>\1</bold>')
@@ -556,7 +568,7 @@ WOK
           para="#{para}\n" unless para.empty?
           @sisu << para
         end
-        new_file_data=@sisu.to_s
+        new_file_data=@sisu.join
         @sisu=new_file_data.scan(/.+/)
         SiSU_Env::SiSU_file.new(@md).mkdir
         filename_sxm=SiSU_Env::SiSU_file.new(@md,@md.fn[:sxd]).mkfile_pwd
