@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -55,6 +59,8 @@
 
 =end
 module SiSU_simple_xml_model_node
+  require "#{SiSU_lib}/particulars"
+  include SiSU_Particulars
   require "#{SiSU_lib}/defaults"
   require "#{SiSU_lib}/param"
   include SiSU_Param
@@ -64,6 +70,7 @@ module SiSU_simple_xml_model_node
   require "#{SiSU_lib}/dal_syntax"
   require "#{SiSU_lib}/dal_doc_str"
   require "#{SiSU_lib}/shared_xml"
+  require "#{SiSU_lib}/shared_sem"
   require "#{SiSU_lib}/xml_format"
   include SiSU_XML_format
   include SiSU_XML_munge
@@ -75,11 +82,12 @@ module SiSU_simple_xml_model_node
     @@fns=nil
     def initialize(opt)
       @opt=opt
+      @particulars=SiSU_Particulars::Combined_singleton.instance.get_env_md(opt)
     end
     def read
       begin
-        @md=SiSU_Param::Parameters.new(@opt).get #bug, relies on info persistence, assumes -m has previously been run
-        @env=SiSU_Env::Info_env.new(@opt.fns)
+        @md=@particulars.md #bug, relies on info persistence, assumes -m has previously been run
+        @env=@particulars.env
         path=@env.path.output_tell
         loc=@env.url.output_tell
         tool=if @opt.cmd =~/[MV]/; "#{Dir.pwd}/#{@md.fn[:sxn]}\n\t#{@env.program.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:sxn]}"
@@ -91,12 +99,12 @@ module SiSU_simple_xml_model_node
         tell.flow if @opt.cmd =~/[MV]/
         unless @@fns==@opt.fns
           @@fns=@opt.fns
-          @@dal_array=[]
+          @@fns_array=[]
         end
-        @dal_array=if @@dal_array.empty?; read_fnm
-        else @@dal_array.dup #.dup #jokes on you
+        @fns_array=if @@fns_array.empty?; read_fnm
+        else @@fns_array.dup #.dup #jokes on you
         end
-        SiSU_simple_xml_model_node::Convert::Songsheet.new(@dal_array,@md,@env).songsheet
+        SiSU_simple_xml_model_node::Convert::Songsheet.new(@fns_array,@particulars).songsheet
       rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure #file closed in songsheet
       end
@@ -110,12 +118,12 @@ module SiSU_simple_xml_model_node
     end
     private
     class Songsheet
-      def initialize(data,md,dir)
-        @data,@md,@env=data,md,dir
+      def initialize(data,particulars)
+        @data,@particulars,@env,@md=data,particulars,particulars.env,particulars.md
       end
       def songsheet
         begin
-          SiSU_simple_xml_model_node::Convert::Scroll.new(@data,@md).songsheet
+          SiSU_simple_xml_model_node::Convert::Scroll.new(@data,@particulars).songsheet
           SiSU_simple_xml_model_node::Convert::Tidy.new(@md,@env).xml if @md.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@md.fn[:sxn]).xml if @md.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
         rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
@@ -131,13 +139,12 @@ module SiSU_simple_xml_model_node
       @@parent={ :ocn=>[],:node=>[] }
       @@offspring={ :ocn=>[],:node=>[] }
       @@current=nil
-      def initialize(data='',md=nil)
-        @data,@md=data,md
+      def initialize(data='',particulars='')
+        @data,@env,@md=data,particulars.env,particulars.md
         @vz=SiSU_Env::Get_init.instance.skin
         @regx=/^(?:(?:<:p[bn]>\s*)?(?::?[A-C]~|\d~)(?:(\S+))?\s+)?(.+)/
         @tab="\t"
         if @md
-          @env=SiSU_Env::Info_env.new(@md.fns)
           @trans=SiSU_XML_munge::Trans.new(@md)
         end
         @sys=SiSU_Env::System_call.new
@@ -222,11 +229,11 @@ WOK
         self
       end
       def build_relationships(o='',lv='')
-        if lv.to_s =~/[0-6]/
+        if lv.inspect =~/[0-6]/
           @node[:ocn][lv]=o.ocn
           @node[:no][lv]=o.node
         end
-        if lv.to_s =~/^[1-6]/; @@current=lv
+        if lv.inspect =~/^[1-6]/; @@current=lv
         end
         if o.node == 1 \
         or lv == 1
@@ -411,6 +418,15 @@ WOK
         obj.each do |o|
           para=o.txt unless o.txt =~/^%% / #comments are lost, consider
           if para
+            if para !~/^\s*(?:%+ |<:code>)/
+              if @md.sem_tag and para =~/[:;]\{|\}[:;]/
+                para=@trans.xml_semantic_tags(para)
+              end
+              if para =~/[:;]\{|\}[:;]/
+                para=SiSU_sem::Tags.new(para,@md).rm.all
+              end
+            end
+            para=SiSU_sem::Tags.new(para,@md).rm.all
             para=@trans.markup_light(para)
             @trans.char_enc.utf8(para) if @sys.locale =~/utf-?8/i #% utf8
             if para =~/\A(?:@|0~)(\S+?):?\s+(.+?)\Z/m # for headers
@@ -576,13 +592,11 @@ WOK
         content << @@xml[:open] << @@xml[:head] << @@xml[:body] << @@xml[:metadata]
         content << @@xml[:owner_details] if @md.stmp =~/\w\w/
         content << @@xml[:tail] << @@xml[:close]
-        Output.new(content.to_s,@md).xml
+        Output.new(content.join,@md).xml
         @@xml={}
       end
     end
     class Output
-      include SiSU_Param
-      include SiSU_Env
       def initialize(data,md)
         @data,@md=data,md
       end
@@ -594,7 +608,7 @@ WOK
           para="#{para}\n" unless para.empty?
           @sisu << para
         end
-        new_file_data=@sisu.to_s
+        new_file_data=@sisu.join
         @sisu=new_file_data.scan(/.+/)
         SiSU_Env::SiSU_file.new(@md).mkdir
         filename_sxm=SiSU_Env::SiSU_file.new(@md,@md.fn[:sxn]).mkfile_pwd
