@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -156,7 +160,7 @@ module SiSU_TexInfo
       data.each do |para|
         # DEBUG 2003w16 this is a kludge, because i could not get parameters
         # from param, Sort out ... revert to more elegant solution
-        if para =~ /<!Th?¡\s+c/
+        if para =~ /<!Th?¡\s+c/u
           @@flag['tables']='y' # KLUDGE get from param
         end
         para.gsub!(/<:p[bn]>/,'')
@@ -239,7 +243,7 @@ module SiSU_TexInfo
       @tex_file=[]
       @@tableheader=0
       data.each do |para|
-        if para =~ /¡|<!T/i
+        if para =~ /¡|<!T/ui
           do_mono=TexInfoFormat::Texinfo.new(para,@md)
           para=do_mono.longtable # using longtable latex package
         end
