@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -371,7 +375,7 @@ WOK
     def longtable
       @end_table="\\end{longtable}"
       @row_break='\\\\\\'
-      if @para[/<!Th?¡\s+c(\d+);(.+?)!>/i]
+      if @para[/<!Th?¡\s+c(\d+);(.+?)!>/ui]
         no_of_cols,cols_width=$1,$2
         @@tableheader=1 if @para =~ /<!Th/i
         @w=cols_width.split(/;\s+/)
@@ -386,17 +390,17 @@ WOK
         @colW=@colW.join
         @@start_table="\\setlength{\\LTleft}{0pt}\n\\setlength{\\LTright}{\\fill}\n" +
           "\\begin{longtable}[hb]#@colW\n"
-        @para.gsub!(/<!Th?¡\s+c\d+?;.+!>/,"#{@@start_table}")
+        @para.gsub!(/<!Th?¡\s+c\d+?;.+!>/u,"#{@@start_table}")
       end
       if @para =~/<!TZ!>/
         @para.gsub!(/<!TZ!>/," #@end_table")
       end
-      @para.gsub!(/<!¡/,'')
+      @para.gsub!(/<!¡/u,'')
       if @@tableheader==1
-        if @para =~/¡\d+?¡(.+?)(?:¡|!)/
+        if @para =~/¡\d+?¡(.+?)(?:¡|!)/u
           tablefoot=para[/\<!f(.+?)!\>/,1]
           @para.gsub!(/\<!f(.+?)!\>/,'')
-          @para.gsub!(/¡\d+?¡(.+?)(?:¡|!)/,
+          @para.gsub!(/¡\d+?¡(.+?)(?:¡|!)/u,
           "{\\begin{tiny} {\\bfseries \\1}\\end{tiny}}&")
           @para.gsub!(/&>\s*$/,
           " #@row_break \\hline\\endhead #@row_break")
@@ -405,8 +409,8 @@ WOK
           @@number_of_cols=0
         end
       else
-        if @para =~/¡\d+?¡(.+?)(?:¡|!)/
-          @para.gsub!(/¡\d+?¡(.+?)(?:¡|!)/,"\\begin{tiny}\\1\\end{tiny}&")
+        if @para =~/¡\d+?¡(.+?)(?:¡|!)/u
+          @para.gsub!(/¡\d+?¡(.+?)(?:¡|!)/u,"\\begin{tiny}\\1\\end{tiny}&")
           @para.gsub!(/&>\s*$/," #@row_break")
         end
       end
@@ -419,7 +423,7 @@ WOK
       @end_table="\\end{tabular}"
       @row_break='\\\\\\\\'
       @break_page="#@row_break\n#@row_break \n"
-      if @para[/<!Th?¡\s+c(\d+);(.+?)!>/i]
+      if @para[/<!Th?¡\s+c(\d+);(.+?)!>/ui]
         no_of_cols,cols_width=$1,$2
         @w=cols_width.split(/;\s+/)
         @colW=[]
@@ -428,13 +432,13 @@ WOK
           @colW << "p{#{col_w}cm}" if col_w
         end
         @@start_table="\\begin{tabular}{#@colW}\n"
-        @para.gsub!(/<!Th?¡\s+c\d+?;.+!>/,"#{@@start_table}")
+        @para.gsub!(/<!Th?¡\s+c\d+?;.+!>/u,"#{@@start_table}")
       end
       if @para =~/<!TZ!>/
         @para.gsub!(/<!TZ!>/,"#@end_table")
         @@table_pg_break_counter=1
       end
-      if @para =~/<!¡/
+      if @para =~/<!¡/u
         if @@table_pg_break_counter==28 # taken from 34 ideal for portrait to 28 which suits landscape
           @para =
             "\n\n#@end_table \n" +
@@ -442,14 +446,14 @@ WOK
             "#{@@start_table}\n"
           @@table_pg_break_counter=1
         else
-          @para.gsub!(/<!¡/,'')
+          @para.gsub!(/<!¡/u,'')
           @@table_pg_break_counter+=1
           tablefoot=@para[/\<!f(.+?)!\>/]
           @para.gsub!(/\<!f(.+?)!\>/,'')
         end
       end
-      if @para =~/¡\d+?¡(.+?)(?:¡|!)/
-      @para.gsub!(/¡\d+?¡(.+?)(?:¡|!)/,"\\begin{tiny}\\1\\end{tiny}&")
+      if @para =~/¡\d+?¡(.+?)(?:¡|!)/u
+      @para.gsub!(/¡\d+?¡(.+?)(?:¡|!)/u,"\\begin{tiny}\\1\\end{tiny}&")
       @para.gsub!(/&>\s*$/,"#@row_break")
       end
       @para
