@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -57,9 +61,9 @@
 module SiSU_TeX
   require 'pstore'
   require "#{SiSU_lib}/defaults"
-  require "#{SiSU_lib}/param"
-  include SiSU_Param
   include SiSU_Viz
+  require "#{SiSU_lib}/particulars"
+  include SiSU_Particulars
   require "#{SiSU_lib}/texpdf_format"
   include SiSU_TeX_Pdf
   @tex_file=@@tex_footnote_array=@@tex_col_w=[]
@@ -75,17 +79,16 @@ module SiSU_TeX
   class Source #Songsheet #<SiSU_Param::MyFiles
     require 'pstore'
     require "#{SiSU_lib}/sysenv"
-    require "#{SiSU_lib}/param"
     include SiSU_Env
-    include SiSU_Param
     include SiSU_Viz
     require "#{SiSU_lib}/dal"
     include SiSU_DAL
     include SiSU_TeX
     def initialize(opt)
       @opt=opt
-      @md=SiSU_Param::Parameters.new(@opt).get
-      @env=SiSU_Env::Info_env.new(@opt.fns)
+      @particulars=SiSU_Particulars::Combined_singleton.instance.get_all(opt)
+      @md=@particulars.md
+      @env=@particulars.env
     end
     def directories
       begin
@@ -104,7 +107,7 @@ module SiSU_TeX
     end
     def songsheet
       begin
-        @md=SiSU_Param::Parameters.new(@opt).get
+        @md=@particulars.md
         tell=SiSU_Screen::Ansi.new(@opt.cmd,'LaTeX/PDF')
         tell.green_title_hi unless @opt.cmd =~/q/
         path=@env.url.output_tell
@@ -112,7 +115,7 @@ module SiSU_TeX
         tell.flow if @opt.cmd =~/[MVv]/
         tell=SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.program.pdf_viewer} #{path}/#{@md.fnb}/#{@md.fn[:pdf_p]}")
         tell.flow if @opt.cmd =~/[MVv]/
-        @md=SiSU_Param::Parameters.new(@opt).get
+        @md=@particulars.md
         my_make=SiSU_Env::Create_file.new(@opt.cmd,@opt.fns)
         $flag=@md.cmd                                                         #introduced to pass 0 for no object citation numbers... to texpdf_format
         @dir_o="#{@env.path.output}/#{@opt.fnb}"
@@ -121,12 +124,11 @@ module SiSU_TeX
         newfilename=filename_index
                                                                              #% needed needs to be reprogrammed !!!
         SiSU_Env::Info_skin.new(@md).select
-        dal_array=SiSU_DAL::Source.new(@opt).get             # dal file drawn here
-        SiSU_TeX::Source::LaTeX_create.new(dal_array,@md,'landscape').songsheet
-        SiSU_TeX::Source::LaTeX_create.new(dal_array,@md,'portrait').songsheet
+        dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
+        SiSU_TeX::Source::LaTeX_create.new(@particulars).songsheet
         dal_array=''
         pwd=Dir.pwd
-        SiSU_TeX::Source::LaTeX_to_pdf.new(@md).latexrun_selective
+        SiSU_TeX::Source::LaTeX_to_pdf.new(@md,@particulars.env).latexrun_selective
         Dir.chdir(pwd)
       rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
@@ -155,9 +157,8 @@ module SiSU_TeX
       require 'fileutils'
       include FileUtils #::Verbose
       @@n_lpdf||=0 #change
-      def initialize(md)
-        @md=md
-        @env=SiSU_Env::Info_env.new(@md.fns)
+      def initialize(md,env)
+        @md,@env=md,env
       end
       def latex_do(texfilename)
         @texfilename=texfilename
@@ -168,24 +169,24 @@ module SiSU_TeX
         cmd=SiSU_Env::System_call.new("#{tex_fn_base}.tex",'',@md.cmd)
         tell=SiSU_Screen::Ansi.new(@md.cmd)
         tell.grey_open unless @md.cmd =~/q/
-        2.times { |i| cmd.latex2pdf unless ("#{tex_fn_base}.tex" !~/\w+/) }
+        2.times { |i| cmd.latex2pdf(@md) unless ("#{tex_fn_base}.tex" !~/\w+/) }
         tell.p_off unless @md.cmd =~/q/
         tell=SiSU_Screen::Ansi.new(@md.cmd,'landscape ->')
         tell.dark_grey_title_hi if @md.cmd =~/[MVv]/
         cmd=SiSU_Env::System_call.new("#{tex_fn_base}.landscape.tex",'',@md.cmd)
         tell.grey_open
-        2.times { |i| cmd.latex2pdf unless ("#{tex_fn_base}.landscape.tex" !~/\w+/) }
+        2.times { |i| cmd.latex2pdf(@md) unless ("#{tex_fn_base}.landscape.tex" !~/\w+/) }
         tell.p_off unless @md.cmd =~/q/
         pwd=Dir.pwd
         portrait_pdf="#{pwd}/#{tex_fn_base}.pdf"
         landscape_pdf="#{pwd}/#{tex_fn_base}.landscape.pdf"
         if FileTest.file?(portrait_pdf)
-          File.install(portrait_pdf,"#@dir_sisu/#{@md.fnb}/#{@md.fn[:pdf_p]}")
-          File.unlink(portrait_pdf)
+          cp(portrait_pdf,"#@dir_sisu/#{@md.fnb}/#{@md.fn[:pdf_p]}")
+          rm(portrait_pdf)
         end
         if FileTest.file?(landscape_pdf)
-          File.install(landscape_pdf,"#@dir_sisu/#{@md.fnb}/#{@md.fn[:pdf_l]}")
-          File.unlink(landscape_pdf)
+          cp(landscape_pdf,"#@dir_sisu/#{@md.fnb}/#{@md.fn[:pdf_l]}")
+          rm(landscape_pdf)
         end
         tell=SiSU_Screen::Ansi.new(@md.cmd,@@n_lpdf,'processed (SiSU LaTeX to pdf - using pdfetex aka. pdftex or pdflatex)')
         tell.generic_number unless @md.cmd =~/q/
@@ -228,17 +229,19 @@ module SiSU_TeX
       end
     end
     class LaTeX_create
-      include SiSU_Param
+      #include SiSU_Param
       @@tex_backslash ||="\\\\"
       @@tilde='\\\\\\~' #?? debug crazy
-      @@tex_head_portrait,@@tex_head_landscape=nil,nil
+      @@tex_head={ :p => nil, :l => nil }
       @@flag_alt,@@flag_group,@@flag_code=false,false,false
       @@dp,@@prefix_b=nil,nil
-      def initialize(data,md,orientation)
-        @data,@md,@orientation=data,md,orientation
-        @env=SiSU_Env::Info_env.new(@md.fns)
+      def initialize(particulars)
+        @particulars=particulars
+        @md=@particulars.md
+        @env=@particulars.env
+        @data=@particulars.dal_array # dal file drawn here
         @st={ :tex=>{} }
-        @tex=SiSU_TeX_Pdf::Use_TeX.new(@md,@orientation)
+        @tex=SiSU_TeX_Pdf::Use_TeX.new(@md)
         @vz=SiSU_Env::Get_init.instance.skin
         @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
         vz=SiSU_Env::Get_init.instance.skin
@@ -253,7 +256,7 @@ module SiSU_TeX
           data=@data
           @@tex_footnote_array=[]
           @@rights=nil
-          tell=SiSU_Screen::Ansi.new(@md.cmd,"pdfTex #@orientation")
+          tell=SiSU_Screen::Ansi.new(@md.cmd,"pdfTex portrait & landscape")
           tell.txt_grey unless @md.cmd =~/q/
           if @md.dc_rights
             use=@md.dc_rights.dup #dup is necessary, else contents of :rights changed
@@ -283,7 +286,6 @@ module SiSU_TeX
            end
           data=number_paras(data,ocn)
           data=markup(data)
-          #data=markup(data).flatten #watch
           output(data)
         rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
         ensure
@@ -300,12 +302,12 @@ module SiSU_TeX
           else para
           end
           if para.class == String
-            @md.flag_tables=true if para =~/<!Th?¡\s+c/
+            @md.flag_tables=true if para =~/<!Th?¡\s+c/u
             do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
             @tex_file << do_mono.special_characters
           elsif para.class == Array
             para.each do |grp|
-              @md.flag_tables=true if grp =~/<!Th?¡\s+c/
+              @md.flag_tables=true if grp =~/<!Th?¡\s+c/u
               do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,grp)
               @tex_file << do_mono.special_characters
             end
@@ -328,19 +330,25 @@ module SiSU_TeX
         end
         @tex_file
       end
+      def tables_hash(md,para)
+        para_p=para.dup #visit
+        do_mono_l=SiSU_TeX_Pdf::Format_text_object.new(md,para)
+        do_mono_p=SiSU_TeX_Pdf::Format_text_object.new(md,para_p)
+        block={
+          :l => do_mono_l.longtable_landscape,
+          :p => do_mono_p.longtable_portrait
+        }
+      end
       def tables(data)
+        @@tableheader={ :p => 0, :l => 0 }
         @tex_file=[]
-        @@tableheader=0
         data.each do |para|
-          if para =~/¡|<!T/
-            do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
-            case @orientation                                                   # using longtable latex package
-            when /landscape/; para=do_mono.longtable_landscape
-            when /portrait/; para=do_mono.longtable_portrait
-            end
+          @tex_file << if para =~/¡|<!T/u
+            tables_hash(@md,para) #Hash result
+          else para
           end
-          @tex_file << para
         end
+        @tex_file
       end
       def enclose(para,type='')
         para.strip!
@@ -350,6 +358,98 @@ module SiSU_TeX
         else para
         end
       end
+      def markup_common(para)
+        tex_f=nil
+        mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
+        if para =~/<:(?:code|alt|verse|group)>/ \
+        or @@flag_alt
+          if para =~/<:(?:code|alt|verse|group)>/
+            @lineone=case para
+            when /<:(?:alt|verse|group)>/; para
+            when /<:code>/; "#{@tex.paraskip_small} \\begin{scriptsize} " + para
+            else 'error' #should never occur
+            end
+          end
+          if para =~/<=curly/ #takes care of escaped curly braces, expand
+            do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
+            para=do_mono.special_characters_curly(para)
+          end
+          regx=/<:((?:code|alt|verse|group)(?:-end)?)>/m
+          x=regx.match(para)[1] if para =~regx
+          x=$1
+          para.gsub!(/\n<:(?:code|alt|verse|group)>\n/m,'')
+          para=enclose(para,'code') unless para =~/^$/
+          if x =~/(?:alt|verse|group)/; @@flag_alt=true
+            if x =~/group/; @@flag_group=true
+            end
+          elsif x =~/code/; @@flag_alt,@@flag_code=true,true
+          elsif @@flag_alt;
+            if para =~ /\}(?:https?|file|ftp)/m
+              para=mono.http #(@orientation)
+            end
+            @group_collect << para #<< "\n\n"
+          end
+          if x =~/(?:code|alt|verse|group)-end/m
+            regx=/(\\+marginpar\{\\+begin\{tiny\}\d+\\+end\{tiny\}\})/
+            y=if para =~regx
+              regx.match(para)[1]
+            else ''
+            end
+            para.gsub!(regx,'')
+            #@group_collect.each{ |x| x.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ') }
+            group_collect=[]
+            group_collect << '\begin{footnotesize} ' unless @@flag_code
+            @group_collect.each do |x|
+              x.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ')
+              x=x.split(/ \\\\ /)
+              group_collect << x
+            end
+            group_collect << ' \end{footnotesize} ' unless @@flag_code
+            @group_collect=group_collect.flatten
+            @lineone.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ')
+            #@group_collect.each{ |x| x.gsub!(/(.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ') }
+            #@lineone.gsub!(/(.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ')
+            insert=[]
+            if para =~/<:code-end>/m
+              insert << y + @lineone << @group_collect << ' \end{scriptsize}' << " #{@tex.paraskip_normal}"
+            else insert << y + @lineone << @group_collect
+            end
+            @@flag_alt,@@flag_group,@@flag_code=false,false,false
+            @group_collect=[]
+            para.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ')
+            #para.gsub!(/(.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ')
+            #@tex_file << insert.flatten
+            tex_f = insert.flatten
+          end
+        else
+          if para =~ /\}(?:https?|file|ftp)/
+            para=mono.http #(@orientation)
+          end
+          case para
+          when /^1#{@@tilde}/;       mono.level1
+          when /^2#{@@tilde}/;       mono.level2
+          when /^3#{@@tilde}/;       mono.level3
+          when /^4#{@@tilde}/;       mono.level4
+          when /^5#{@@tilde}/;       mono.level5
+          when /^6#{@@tilde}/;       mono.level6
+          when /^<:i([1-9])>/;       mono.indent($1)
+          when /<:=/;                mono.symbol_graphic #watch
+          when /^\s*<:image\s+/;     mono.image
+          when /\}image/;            mono.png
+          else
+            para.strip!
+            para=enclose(para) unless para =~/^$/
+          end
+          para.gsub!(/(\.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ')   #% tread with care
+          #para.gsub!(/(.#{@@tilde}(?:\\~\S+)?\s*|<:\S+>|<!.*?!>|<!>)/,' ')  #KEEP reference, problem escaping open curly braces \{
+          if para =~/<=curly/ #takes care of escaped curly braces, expand
+            do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
+            para=do_mono.special_characters_curly(para)
+          end
+          tex_f = para
+        end
+        tex_f
+      end
       def markup(data)
         @tex_file=[]
         md={}
@@ -357,12 +457,10 @@ module SiSU_TeX
         home=@vz.txt_home.gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>|\\\\/,' - ') #no line splitting in heading neither html nor latex
         title=@md.title.gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>|\\\\/,' - ') #no line splitting in heading neither html nor latex
         subtitle=@md.subtitle.gsub(/<(br|p)>|<\/\s*(br|p)>|<(br|p)\s*\/>|\\\\/,' - ') if @md.subtitle #no line splitting in heading neither html nor latex
-        orient=SiSU_TeX_Pdf::Format_text_object.new(@md,@orientation,"#{home}: - #{title} #{subtitle}") #.new
-        if @orientation =~/portrait/
-          @@tex_head_portrait=orient.document_head_with_orientation
-        elsif @orientation =~/landscape/
-          @@tex_head_landscape=orient.document_head_with_orientation
-        end
+        orient_portrait=SiSU_TeX_Pdf::Format_text_object.new(@md,'portrait',"#{home}: - #{title} #{subtitle}")
+        orient_landscape=SiSU_TeX_Pdf::Format_text_object.new(@md,'landscape',"#{home}: - #{title} #{subtitle}")
+        @@tex_head[:p]=orient_portrait.document_head_with_orientation
+        @@tex_head[:l]=orient_landscape.document_head_with_orientation
         @tex_file <<<<WOK
 #{@tex.header}#{@tex.footer}
 \\tolerance=500
@@ -377,39 +475,25 @@ WOK
         #else                               ''
         #end
         @copymark='' #check and remove as now is superflous
-        if @orientation =~/landscape/ # using longtable latex package
-          @tex_file << SiSU_TeX_Pdf::Format_text_object.new(@md,@md.title,@md.subtitle).title_landscape
-          if @md.dc_creator
-            do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,@md.dc_creator)
-            creator=do_mono.special_characters
-            @tex_file << if @md.creator_home
-              <<WOK
+        x={}
+        x[:l]=SiSU_TeX_Pdf::Format_text_object.new(@md,@md.title,@md.subtitle).title_landscape
+        x[:p]=SiSU_TeX_Pdf::Format_text_object.new(@md,@md.title,@md.subtitle).title_portrait
+        @tex_file << x
+        x=nil
+        if @md.dc_creator
+          do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,@md.dc_creator)
+          creator=do_mono.special_characters
+          @tex_file << if @md.creator_home
+            <<WOK
 
 \\author{\\href{#{@md.creator_home}}{#@copymark \\textnormal{#{creator}}}}
 WOK
-            else "\n\\author{#@copymark \\textnormal{#{creator}}}"
-            end
-          end
-          @tex_file << unless @md.fnb =~/^mail\s*$/
-            "\n\\date{\\begin{footnotesize} copy @ #{@tex.site} \\end{footnotesize} #{sisu_rc_footnote}}"
-          else "\\date"
-          end
-        else #portrait
-          @tex_file << SiSU_TeX_Pdf::Format_text_object.new(@md,@md.title,@md.subtitle).title_portrait
-          if @md.dc_creator
-            creator=@md.dc_creator
-            @tex_file << if @md.creator_home
-              <<WOK
-
-\\author{\\href{#{@md.creator_home}}{#@copymark \\textnormal{#{creator}}}}
-WOK
-            else "\n\\author{#@copymark \\textnormal{#{creator}}}"
-            end
-           end
-          @tex_file << unless @md.fnb =~/^mail\s*$/; "\n\\date{\\begin{footnotesize} copy @ #{@tex.site} \\end{footnotesize} #{sisu_rc_footnote}}"
-          else                                       "\\date"
+          else "\n\\author{#@copymark \\textnormal{#{creator}}}"
           end
         end
+        @tex_file << unless @md.fnb =~/^mail\s*$/; "\n\\date{\\begin{footnotesize} copy @ #{@tex.site} \\end{footnotesize} #{sisu_rc_footnote}}"
+        else                                       "\\date"
+        end
         @tex_file <<<<WOK
 \\pagenumbering{roman}\\maketitle
 \\pagestyle{fancy}
@@ -423,104 +507,38 @@ WOK
         else                         @tex.doc_no_sc_info
         end
         @tex_file << @tex.manifest_info
-        @tex_file << @tex.newpage
-        @tex_file <<<<WOK
+        x={}
+        x[:l] =<<WOK
+#{@tex.newpage('landscape')}
 \\pagestyle{fancy}
 \\tableofcontents
-#{@tex.newpage}
+#{@tex.newpage('landscape')}
 \\pagenumbering{arabic}
 #{@tex.paraskip_normal}
+#{@tex.newpage('landscape')}
 WOK
-        @tex_file << @tex.newpage
+        x[:p] =<<WOK
+#{@tex.newpage('portrait')}
+\\pagestyle{fancy}
+\\tableofcontents
+#{@tex.newpage('portrait')}
+\\pagenumbering{arabic}
+#{@tex.paraskip_normal}
+#{@tex.newpage('portrait')}
+WOK
+        @tex_file << x
+        x=nil
         @group_collect=[]
         data.each do |para|                                                      #% case follows with levels 1-6 indents & graphics
-          mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
-          if para =~/<:(?:code|alt|verse|group)>/ \
-          or @@flag_alt
-            if para =~/<:(?:code|alt|verse|group)>/
-              @lineone=case para
-              when /<:(?:alt|verse|group)>/; para
-              when /<:code>/; "#{@tex.paraskip_small} \\begin{scriptsize} " + para
-              else 'error' #should never occur
-              end
-            end
-            if para =~/<=curly/ #takes care of escaped curly braces, expand
-              do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
-              para=do_mono.special_characters_curly(para)
-            end
-            regx=/<:((?:code|alt|verse|group)(?:-end)?)>/m
-            x=regx.match(para)[1] if para =~regx
-            x=$1
-            para.gsub!(/\n<:(?:code|alt|verse|group)>\n/m,'')
-            para=enclose(para,'code') unless para =~/^$/
-            if x =~/(?:alt|verse|group)/; @@flag_alt=true
-              if x =~/group/; @@flag_group=true
-              end
-            elsif x =~/code/; @@flag_alt,@@flag_code=true,true
-            elsif @@flag_alt;
-              if para =~ /\}(?:https?|file|ftp)/m
-                para=mono.http(@orientation)
-              end
-              @group_collect << para #<< "\n\n"
-            end
-            if x =~/(?:code|alt|verse|group)-end/m
-              regx=/(\\+marginpar\{\\+begin\{tiny\}\d+\\+end\{tiny\}\})/
-              y=if para =~regx
-                regx.match(para)[1]
-              else ''
-              end
-              para.gsub!(regx,'')
-              #@group_collect.each{ |x| x.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ') }
-              group_collect=[]
-              group_collect << '\begin{footnotesize} ' unless @@flag_code
-              @group_collect.each do |x|
-                x.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ')
-                x=x.split(/ \\\\ /)
-                group_collect << x
-              end
-              group_collect << ' \end{footnotesize} ' unless @@flag_code
-              @group_collect=group_collect.flatten
-              @lineone.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ')
-              #@group_collect.each{ |x| x.gsub!(/(.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ') }
-              #@lineone.gsub!(/(.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ')
-              insert=[]
-              if para =~/<:code-end>/m
-                insert << y + @lineone << @group_collect << ' \end{scriptsize}' << " #{@tex.paraskip_normal}"
-              else insert << y + @lineone << @group_collect
-              end
-              @@flag_alt,@@flag_group,@@flag_code=false,false,false
-              @group_collect=[]
-              para.gsub!(/(<:\S+>|<!.*?!>|<!>)/,' ')
-              #para.gsub!(/(.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ')
-              @tex_file << insert.flatten
-            end
-          else
-            if para =~ /\}(?:https?|file|ftp)/
-              para=mono.http(@orientation)
-            end
-            case para
-            when /^1#{@@tilde}/;       mono.level1
-            when /^2#{@@tilde}/;       mono.level2
-            when /^3#{@@tilde}/;       mono.level3
-            when /^4#{@@tilde}/;       mono.level4
-            when /^5#{@@tilde}/;       mono.level5
-            when /^6#{@@tilde}/;       mono.level6
-            when /^<:i([1-9])>/;       mono.indent($1)
-            when /<:=/;                mono.symbol_graphic #watch
-            when /^\s*<:image\s+/;     mono.image
-            when /\}image/;            mono.png
-            else
-              para.strip!
-              para=enclose(para) unless para =~/^$/
-            end
-            para.gsub!(/(\.#{@@tilde}\S*\s*|<:\S+>|<!.*?!>|<!>)/,' ')   #% tread with care
-            #para.gsub!(/(.#{@@tilde}(?:\\~\S+)?\s*|<:\S+>|<!.*?!>|<!>)/,' ')  #KEEP reference, problem escaping open curly braces \{
-            if para =~/<=curly/ #takes care of escaped curly braces, expand
-              do_mono=SiSU_TeX_Pdf::Format_text_object.new(@md,para)
-              para=do_mono.special_characters_curly(para)
-            end
-            @tex_file << para
+          if para.class == String
+            para=markup_common(para)
+          elsif para.class == Hash
+            para={ 
+              :p => markup_common(para[:p]),
+              :l => markup_common(para[:l])
+            }
           end
+          @tex_file << para
         end
         @tex_file << "\n\\newpage\n" # was \\pagebreak\n
         @md.subtitle_tex=@md.subtitle.dup if @md.subtitle
@@ -570,62 +588,79 @@ WOK
         end
         @tex_file << "\n\\end{document}"
       end
-      def number_paras(data,ocn)
-        @tex_file=[]
-        data.each do |para|
-          if para =~/<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/ \
-          and para !~/\\end\{longtable\}|<EOF>/ #catch <!TZ!>
-            m=/(.+?)<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/m
-            parablock=para[m,1]
-            paranum=if ocn; para[m,2]
-            else ''
-            end
-            do_duo=SiSU_TeX_Pdf::Format_text_object.new(@md,parablock,paranum)
-            para=do_duo.para_num if parablock
-          elsif para =~/^<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/ #2005 this is added for tables, rationalise
-            m=/<~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/m
-            paranum=para[m,1]
-            para.gsub!(/<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>/,'')
-            para="\\marginpar{\\begin{tiny}#{paranum}\\end{tiny}}" + para
-            #para="\\marginpar{\\begin{tiny}#{paranum}\\end{tiny}}"
-          #elsif para =~/<!T.+?!~\d+?>/
-          elsif para =~/^<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+>/ #extra 2005 this is added for tables, rationalise
-            m=/<~(\d+);[oh]\d+;\w\d+>/m
-            paranum=para[m,1]
-            para.gsub!(/<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+>/,'')
-            para="\\marginpar{\\begin{tiny}#{paranum}\\end{tiny}}" + para
-          elsif para =~/\\end\{longtable\}/ #catch <!TZ!>
-            para.gsub!(/<\\~\d+>|<\\~(\d+);(?:[ohm]|[0-6]:)\d+;\w\d+><#@dp:#@dp>/,'')
-            para.gsub!(/<\\~\d+>|<\\~(\d+);(?:[ohm]|[0-6]:)\d+;\w\d+>/,'') #extra
+      def number_paras_numbering(para,ocn)
+        if para =~/<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/ \
+        and para !~/\\end\{longtable\}|<EOF>/ #catch <!TZ!>
+          m=/(.+?)<\\~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/m
+          parablock=para[m,1]
+          paranum=if ocn; para[m,2]
+          else ''
           end
-          @tex_file << para
+          do_duo=SiSU_TeX_Pdf::Format_text_object.new(@md,parablock,paranum)
+          para=do_duo.para_num if parablock
+        elsif para =~/^<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/ #2005 this is added for tables, rationalise
+          m=/<~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/m
+          paranum=para[m,1]
+          para.gsub!(/<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+><#@dp:#@dp>/,'')
+          para="\\marginpar{\\begin{tiny}#{paranum}\\end{tiny}}" + para
+        elsif para =~/^<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+>/ #extra 2005 this is added for tables, rationalise
+          m=/<~(\d+);[oh]\d+;\w\d+>/m
+          paranum=para[m,1]
+          para.gsub!(/<~\d+;(?:[oh]|[0-6]:)\d+;\w\d+>/,'')
+          para="\\marginpar{\\begin{tiny}#{paranum}\\end{tiny}}" + para
+        elsif para =~/\\end\{longtable\}/ #catch <!TZ!>
+          para.gsub!(/<\\~\d+>|<\\~(\d+);(?:[ohm]|[0-6]:)\d+;\w\d+><#@dp:#@dp>/,'')
+          para.gsub!(/<\\~\d+>|<\\~(\d+);(?:[ohm]|[0-6]:)\d+;\w\d+>/,'') #extra
         end
-        @tex_file
+        para
       end
-      def output(data)
-        data.flatten!
-        data.compact!
-        fns_l=@md.fns.gsub(/~/,'-') #this is a sorry fix, but necessary as it appears latex programs like not ~
-        if @orientation =~/landscape/
-          filename_tex_landscape=File.new("#{@env.path.tex}/#{fns_l}.landscape.tex",'w+')
-          filename_tex_landscape << @@tex_head_landscape
-          data.each do |para|
-            para.gsub!(/^\s+/,'')
-            filename_tex_landscape.puts para,"\n" if para !~/\A\s*\Z/
+      def number_paras(data,ocn)
+        tex_file=[]
+        data.each do |para|
+          para=if para.class == Hash \
+          and (para[:p] and para[:l])
+            para = {
+              :p => number_paras_numbering(para[:p],ocn),
+              :l => number_paras_numbering(para[:l],ocn)
+            }
+          else #elsif para.class == String
+            number_paras_numbering(para,ocn)
           end
-          filename_tex_landscape.close
-          @@tex_head_landscape=[]
-        elsif @orientation =~/portrait/
-          filename_tex_portrait=File.new("#{@env.path.tex}/#{fns_l}.tex",'w+')
-          filename_tex_portrait << @@tex_head_portrait
-          data.each do |para|
-            para.gsub!(/^\s+/,'')
-            filename_tex_portrait.puts para,"\n" if para !~/\A\s*\Z/
-          end
-          filename_tex_portrait.close
-          @@tex_head_portrait=[]
+          tex_file << para
         end
-        data=[]
+        tex_file
+      end
+      def output(array)
+        array.flatten!
+        array.compact!
+        fns_l=@md.fns.gsub(/~/,'-') #this is a sorry fix, but necessary as it appears latex programs like not ~
+        filename_tex_landscape=File.new("#{@env.path.tex}/#{fns_l}.landscape.tex",'w+')
+        filename_tex_portrait=File.new("#{@env.path.tex}/#{fns_l}.tex",'w+')
+        filename_tex_portrait << @@tex_head[:p]
+        filename_tex_landscape << @@tex_head[:l]
+        array.each do |para|
+          case para
+          when String
+            para.gsub!(/^\s+/,'')
+            if para !~/\A\s*\Z/
+              filename_tex_portrait.puts para,"\n"
+              filename_tex_landscape.puts para,"\n"
+            end
+          when Hash
+            para[:p].gsub!(/^\s+/,'')
+            para[:l].gsub!(/^\s+/,'')
+            if para[:p] !~/\A\s*\Z/
+              filename_tex_portrait.puts para[:p],"\n"
+            end
+            if para[:l] !~/\A\s*\Z/
+              filename_tex_landscape.puts para[:l],"\n"
+            end
+          end
+        end
+        filename_tex_portrait.close
+        filename_tex_landscape.close
+        @@tex_head={} #@@tex_head={ :p => nil, :l => nil }
+        array=[]
       end
     end
   end
