@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -55,11 +59,11 @@
 
 =end
 module SiSU_urls
+  require "#{SiSU_lib}/particulars"
+  include SiSU_Particulars
   require "#{SiSU_lib}/sysenv"
   include SiSU_Env
   include SiSU_Screen
-  require "#{SiSU_lib}/param"
-  include SiSU_Param
   class Source
     attr_reader :opt
     def initialize(opt)
@@ -74,15 +78,15 @@ module SiSU_urls
     end
   end
   class Output_urls
-    include SiSU_Param
     attr_reader :fns,:fnb,:cmd,:dir,:m_regular,:u
     def initialize(opt)
       @opt=opt
+      @particulars=SiSU_Particulars::Combined_singleton.instance.get_env_md(opt)
       fn_set_lang=SiSU_Env::Standardise_language.new.file_to_language(@opt.fns)
       @cmd=@opt.cmd
-      env=SiSU_Env::Env_call.new(@opt.fns)
-      @fnb=env.fnb
-      @env=SiSU_Env::Info_env.new(@opt.fns)
+      @md=@particulars.md
+      @env=@particulars.env
+      @fnb=@env.fnb
       fn_set_lang=SiSU_Env::Standardise_language.new.file_to_language(@opt.fns)
       @fnl=@env.i18n.lang_filename(fn_set_lang[:c])
       @fn=SiSU_Env::Env_call.new(@opt.fns).lang(fn_set_lang[:c])
