@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -56,9 +60,9 @@
 =end
 module SiSU_XML_DOM
   require "#{SiSU_lib}/defaults"
-  require "#{SiSU_lib}/param"
-  include SiSU_Param
   include SiSU_Viz
+  require "#{SiSU_lib}/particulars"
+  include SiSU_Particulars
   require "#{SiSU_lib}/sysenv"
   include SiSU_Env
   require "#{SiSU_lib}/dal"
@@ -73,11 +77,11 @@ module SiSU_XML_DOM
   class Source
     def initialize(opt)
       @opt=opt
+      @particulars=SiSU_Particulars::Combined_singleton.instance.get_all(opt)
     end
     def read
       begin
-        @md=SiSU_Param::Parameters.new(@opt).get
-        @env=SiSU_Env::Info_env.new(@opt.fns)
+        @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
         path=@env.path.output_tell
         loc=@env.url.output_tell
         tool=if @opt.cmd =~/[MV]/; "#{@env.program.web_browser} #{loc}/#{@md.fnb}/#{@md.fn[:dom]}\n\t#{@env.program.xml_viewer} #{path}/#{@md.fnb}/#{@md.fn[:dom]}"
@@ -86,8 +90,7 @@ module SiSU_XML_DOM
         end
         SiSU_Screen::Ansi.new(@opt.cmd,'invert','XML DOM',tool).colorize unless @opt.cmd =~/q/
         SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.path.output_tell}/#{@md.fnb}/#{@md.fn[:dom]}").flow if @opt.cmd =~/[MV]/
-        @dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
-        SiSU_XML_DOM::Source::Songsheet.new(@dal_array,@md,@env).songsheet
+        SiSU_XML_DOM::Source::Songsheet.new(@particulars).songsheet
       rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
         #file closed in songsheet
@@ -95,12 +98,12 @@ module SiSU_XML_DOM
     end
     private
     class Songsheet
-      def initialize(data,md='',dir='')
-        @data,@md,@env=data,md,dir
+      def initialize(particulars)
+        @env,@md,@dal_array,@particulars=particulars.env,particulars.md,particulars.dal_array,particulars
       end
       def songsheet
         begin
-          SiSU_XML_DOM::Source::Scroll.new(@data,@md).songsheet
+          SiSU_XML_DOM::Source::Scroll.new(@particulars).songsheet
           SiSU_XML_DOM::Source::Tidy.new(@md,@env).xml if @md.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
           SiSU_Rexml::Rexml.new(@md,@md.fn[:dom]).xml if @md.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
         rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
@@ -113,8 +116,8 @@ module SiSU_XML_DOM
       require "#{SiSU_lib}/shared_txt"
       include SiSU_text_utils
       @@dp=nil
-      def initialize(data='',md='')
-        @data,@md=data,md
+      def initialize(particulars)
+        @env,@md,@dal_array=particulars.env,particulars.md,particulars.dal_array
         @vz=SiSU_Env::Get_init.instance.skin
         @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
         @regx=/^(?:(?:<:p[bn]>\s*)?\d~(?:(\S+))?\s+)?(.+?)\s*<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><#@dp:#@dp>$/ #
@@ -124,7 +127,7 @@ module SiSU_XML_DOM
       end
       def songsheet
         pre
-        @data=markup(@data)
+        @data=markup(@dal_array)
         post
         publish
       end
@@ -562,4 +565,3 @@ WOK
   end
 end
 __END__
-
